"""
Tests
"""

import pytest

from ArWikiCats.legacy_bots.make_bots.get_helps import get_suffix

data_countries_from_nat = {
    "afghanistan national football team managers": ("national football team managers", "afghanistan"),
    "argentina women's international footballers": ("women's international footballers", "argentina"),
    "australia international soccer players": ("international soccer players", "australia"),
    "australia national women's wheelchair basketball team": (
        "national women's wheelchair basketball team",
        "australia",
    ),
    "canada men's international soccer players": ("men's international soccer players", "canada"),
    "england amateur international footballers": ("amateur international footballers", "england"),
    "georgia (country)": ("(country)", "georgia"),
    "georgia (u.s. state)": ("(u.s. state)", "georgia"),
    "new zealand wheelchair racers": ("wheelchair racers", "new zealand"),
    "new zealand wheelchair rugby players": ("wheelchair rugby players", "new zealand"),
    "new zealand wheelchair rugby": ("wheelchair rugby", "new zealand"),
    "south africa international soccer players": ("international soccer players", "south africa"),
    "united kingdom from aden": ("from aden", "united kingdom"),
    "united states by state": ("by state", "united states"),
}


@pytest.mark.parametrize("category, expected", data_countries_from_nat.items(), ids=lambda x: x[0])
def test_countries_from_nat(category: str, expected: tuple[str, str]) -> None:
    # Test with a valid category and nat
    result = get_suffix(category, "countries_from_nat")
    assert result == expected


def test_get_suffix() -> None:
    # Test with an empty list of keys (should return empty tuple)
    result = get_suffix("test category", "nat")
    assert isinstance(result, tuple)
    assert len(result) == 2
    assert isinstance(result[0], str)
    assert isinstance(result[1], str)


data_nat = {
    "afghan competitors": ("competitors", "afghan"),
    "afghan diplomats": ("diplomats", "afghan"),
    "afghan emigrants": ("emigrants", "afghan"),
    "afghan expatriates": ("expatriates", "afghan"),
    "african national women's football teams": ("national women's football teams", "african"),
    "africanamerican history": ("history", "africanamerican"),
    "albanian sports coaches": ("sports coaches", "albanian"),
    "american award winners": ("award winners", "american"),
    "american basketball coaches": ("basketball coaches", "american"),
    "american basketball players": ("basketball players", "american"),
    "american cinema editors": ("cinema editors", "american"),
    "american cinema": ("cinema", "american"),
    "american comics": ("comics", "american"),
    "american films": ("films", "american"),
    "american men wheelchair racers": ("men wheelchair racers", "american"),
    "american men's wheelchair basketball players": ("men's wheelchair basketball players", "american"),
    "american national softball team managers": ("national softball team managers", "american"),
    "american national softball team": ("national softball team", "american"),
    "american national softball": ("national softball", "american"),
    "american nuclear medicine physicians": ("nuclear medicine physicians", "american"),
    "american people of": ("of", "american"),
    "american people": ("people", "american"),
    "american television episodes": ("television episodes", "american"),
    "american television seasons": ("television seasons", "american"),
    "american television series basedon british television series": (
        "television series basedon british television series",
        "american",
    ),
    "american television series basedon british": ("television series basedon british", "american"),
    "american television series debuts": ("television series debuts", "american"),
    "american television series endings": ("television series endings", "american"),
    "american television series": ("television series", "american"),
    "american television": ("television", "american"),
    "american wheelchair basketball players": ("wheelchair basketball players", "american"),
    "american wheelchair curlers": ("wheelchair curlers", "american"),
    "american wheelchair curling champions": ("wheelchair curling champions", "american"),
    "american wheelchair discus throwers": ("wheelchair discus throwers", "american"),
    "american wheelchair javelin throwers": ("wheelchair javelin throwers", "american"),
    "american wheelchair racers": ("wheelchair racers", "american"),
    "american wheelchair rugby players": ("wheelchair rugby players", "american"),
    "american wheelchair shot putters": ("wheelchair shot putters", "american"),
    "american wheelchair sports competitors": ("wheelchair sports competitors", "american"),
    "american wheelchair tennis players": ("wheelchair tennis players", "american"),
    "american wheelchair track and field athletes": ("wheelchair track and field athletes", "american"),
    "american wheelchair track": ("wheelchair track", "american"),
    "american women wheelchair racers": ("women wheelchair racers", "american"),
    "argentine multi instrumentalists": ("multi instrumentalists", "argentine"),
    "argentine multi-instrumentalists": ("multi-instrumentalists", "argentine"),
    "argentine songwriters": ("songwriters", "argentine"),
    "australian internet celebrities": ("internet celebrities", "australian"),
    "australian male sprinters": ("male sprinters", "australian"),
    "australian men wheelchair racers": ("men wheelchair racers", "australian"),
    "australian men's wheelchair basketball players": ("men's wheelchair basketball players", "australian"),
    "australian open by year – wheelchair events": ("open by year – wheelchair events", "australian"),
    "australian open by year – wheelchair": ("open by year – wheelchair", "australian"),
    "australian wheelchair basketball players": ("wheelchair basketball players", "australian"),
    "australian wheelchair racers": ("wheelchair racers", "australian"),
    "australian wheelchair rugby players": ("wheelchair rugby players", "australian"),
    "australian wheelchair tennis players": ("wheelchair tennis players", "australian"),
    "australian women wheelchair racers": ("women wheelchair racers", "australian"),
    "australian women's wheelchair basketball players": ("women's wheelchair basketball players", "australian"),
    "austrian men wheelchair racers": ("men wheelchair racers", "austrian"),
    "austrian wheelchair racers": ("wheelchair racers", "austrian"),
    "belgian athletics coaches": ("athletics coaches", "belgian"),
    "belgian men wheelchair racers": ("men wheelchair racers", "belgian"),
    "belgian wheelchair racers": ("wheelchair racers", "belgian"),
    "belgian women wheelchair racers": ("women wheelchair racers", "belgian"),
    "brazilian men wheelchair racers": ("men wheelchair racers", "brazilian"),
    "brazilian wheelchair racers": ("wheelchair racers", "brazilian"),
    "brazilian women wheelchair racers": ("women wheelchair racers", "brazilian"),
    "british editorial cartoonists": ("editorial cartoonists", "british"),
    "british men wheelchair racers": ("men wheelchair racers", "british"),
    "british men's wheelchair basketball players": ("men's wheelchair basketball players", "british"),
    "british rail": ("rail", "british"),
    "british reality television series": ("reality television series", "british"),
    "british television chefs": ("television chefs", "british"),
    "british television series characters by series": ("television series characters by series", "british"),
    "british television series characters": ("television series characters", "british"),
    "british television series": ("television series", "british"),
    "british wheelchair basketball players": ("wheelchair basketball players", "british"),
    "british wheelchair curlers": ("wheelchair curlers", "british"),
    "british wheelchair racers": ("wheelchair racers", "british"),
    "british wheelchair rugby players": ("wheelchair rugby players", "british"),
    "british wheelchair shot putters": ("wheelchair shot putters", "british"),
    "british wheelchair sports competitors": ("wheelchair sports competitors", "british"),
    "british wheelchair tennis players": ("wheelchair tennis players", "british"),
    "british wheelchair track and field athletes": ("wheelchair track and field athletes", "british"),
    "british wheelchair track": ("wheelchair track", "british"),
    "british women wheelchair racers": ("women wheelchair racers", "british"),
    "british women's wheelchair basketball players": ("women's wheelchair basketball players", "british"),
    "cameroonian men's wheelchair basketball players": ("men's wheelchair basketball players", "cameroonian"),
    "cameroonian wheelchair basketball players": ("wheelchair basketball players", "cameroonian"),
    "canadian male wheelchair basketball players": ("male wheelchair basketball players", "canadian"),
    "canadian men wheelchair racers": ("men wheelchair racers", "canadian"),
    "canadian men's wheelchair basketball players": ("men's wheelchair basketball players", "canadian"),
    "canadian nuclear medicine physicians": ("nuclear medicine physicians", "canadian"),
    "canadian sports businesspeople": ("sports businesspeople", "canadian"),
    "canadian wheelchair basketball players": ("wheelchair basketball players", "canadian"),
    "canadian wheelchair curlers": ("wheelchair curlers", "canadian"),
    "canadian wheelchair curling champions": ("wheelchair curling champions", "canadian"),
    "canadian wheelchair curling championships": ("wheelchair curling championships", "canadian"),
    "canadian wheelchair racers": ("wheelchair racers", "canadian"),
    "canadian wheelchair rugby players": ("wheelchair rugby players", "canadian"),
    "canadian wheelchair sports competitors": ("wheelchair sports competitors", "canadian"),
    "canadian women wheelchair racers": ("women wheelchair racers", "canadian"),
    "canadian women's wheelchair basketball players": ("women's wheelchair basketball players", "canadian"),
    "cape verdean football managers": ("football managers", "cape verdean"),
    "celtic mythology": ("mythology", "celtic"),
    "chinese men wheelchair racers": ("men wheelchair racers", "chinese"),
    "chinese wheelchair curlers": ("wheelchair curlers", "chinese"),
    "chinese wheelchair racers": ("wheelchair racers", "chinese"),
    "chinese women wheelchair racers": ("women wheelchair racers", "chinese"),
    "croatian nuclear medicine physicians": ("nuclear medicine physicians", "croatian"),
    "czech wheelchair racers": ("wheelchair racers", "czech"),
    "danish wheelchair curlers": ("wheelchair curlers", "danish"),
    "danish wheelchair racers": ("wheelchair racers", "danish"),
    "dutch explorers": ("explorers", "dutch"),
    "dutch men wheelchair racers": ("men wheelchair racers", "dutch"),
    "dutch men's wheelchair basketball players": ("men's wheelchair basketball players", "dutch"),
    "dutch wheelchair basketball players": ("wheelchair basketball players", "dutch"),
    "dutch wheelchair racers": ("wheelchair racers", "dutch"),
    "dutch wheelchair tennis players": ("wheelchair tennis players", "dutch"),
    "dutch women wheelchair racers": ("women wheelchair racers", "dutch"),
    "dutch women's wheelchair basketball players": ("women's wheelchair basketball players", "dutch"),
    "egyptian female sport shooters": ("female sport shooters", "egyptian"),
    "egyptian male sport shooters": ("male sport shooters", "egyptian"),
    "egyptian mythology": ("mythology", "egyptian"),
    "egyptian oncologists": ("oncologists", "egyptian"),
    "egyptian sport shooters": ("sport shooters", "egyptian"),
    "emirati football": ("football", "emirati"),
    "emirati wheelchair racers": ("wheelchair racers", "emirati"),
    "english men wheelchair racers": ("men wheelchair racers", "english"),
    "english wheelchair curlers": ("wheelchair curlers", "english"),
    "english wheelchair racers": ("wheelchair racers", "english"),
    "english women wheelchair racers": ("women wheelchair racers", "english"),
    "equatoguinean female footballers": ("female footballers", "equatoguinean"),
    "ethiopian basketball players": ("basketball players", "ethiopian"),
    "european national under 21 football teams": ("national under 21 football teams", "european"),
    "european national under-21 football teams": ("national under-21 football teams", "european"),
    "european rugby union by country": ("rugby union by country", "european"),
    "european rugby union": ("rugby union", "european"),
    "european wheelchair basketball championship": ("wheelchair basketball championship", "european"),
    "european wheelchair handball nations’ tournament": ("wheelchair handball nations’ tournament", "european"),
    "european women": ("women", "european"),
    "finnish men wheelchair racers": ("men wheelchair racers", "finnish"),
    "finnish wheelchair curlers": ("wheelchair curlers", "finnish"),
    "finnish wheelchair curling champions": ("wheelchair curling champions", "finnish"),
    "finnish wheelchair racers": ("wheelchair racers", "finnish"),
    "finnish women wheelchair racers": ("women wheelchair racers", "finnish"),
    "french comic strips": ("comic strips", "french"),
    "french men wheelchair racers": ("men wheelchair racers", "french"),
    "french men's wheelchair basketball players": ("men's wheelchair basketball players", "french"),
    "french open by year – wheelchair events": ("open by year – wheelchair events", "french"),
    "french open by year – wheelchair": ("open by year – wheelchair", "french"),
    "french tennis players": ("tennis players", "french"),
    "french wheelchair basketball players": ("wheelchair basketball players", "french"),
    "french wheelchair racers": ("wheelchair racers", "french"),
    "french wheelchair tennis players": ("wheelchair tennis players", "french"),
    "french women's wheelchair basketball players": ("women's wheelchair basketball players", "french"),
    "gabonese men wheelchair racers": ("men wheelchair racers", "gabonese"),
    "gabonese wheelchair racers": ("wheelchair racers", "gabonese"),
    "german footballers": ("footballers", "german"),
    "german men wheelchair racers": ("men wheelchair racers", "german"),
    "german men's wheelchair basketball players": ("men's wheelchair basketball players", "german"),
    "german nuclear medicine physicians": ("nuclear medicine physicians", "german"),
    "german wheelchair basketball players": ("wheelchair basketball players", "german"),
    "german wheelchair curlers": ("wheelchair curlers", "german"),
    "german wheelchair racers": ("wheelchair racers", "german"),
    "german wheelchair tennis players": ("wheelchair tennis players", "german"),
    "german women's wheelchair basketball players": ("women's wheelchair basketball players", "german"),
    "icelandic male athletes": ("male athletes", "icelandic"),
    "icelandic male runners": ("male runners", "icelandic"),
    "icelandic male steeplechase runners": ("male steeplechase runners", "icelandic"),
    "indian cricketers": ("cricketers", "indian"),
    "iranian nuclear medicine physicians": ("nuclear medicine physicians", "iranian"),
    "irish football managers": ("football managers", "irish"),
    "irish men wheelchair racers": ("men wheelchair racers", "irish"),
    "irish wheelchair racers": ("wheelchair racers", "irish"),
    "irish women wheelchair racers": ("women wheelchair racers", "irish"),
    "israeli men wheelchair racers": ("men wheelchair racers", "israeli"),
    "israeli men's wheelchair basketball players": ("men's wheelchair basketball players", "israeli"),
    "israeli people of": ("of", "israeli"),
    "israeli wheelchair basketball players": ("wheelchair basketball players", "israeli"),
    "israeli wheelchair racers": ("wheelchair racers", "israeli"),
    "israeli wheelchair tennis players": ("wheelchair tennis players", "israeli"),
    "israeli women's wheelchair basketball players": ("women's wheelchair basketball players", "israeli"),
    "italian defectors to the soviet union": ("defectors to the soviet union", "italian"),
    "italian defectors": ("defectors", "italian"),
    "italian wheelchair curlers": ("wheelchair curlers", "italian"),
    "italian wheelchair racers": ("wheelchair racers", "italian"),
    "ivorian descent": ("descent", "ivorian"),
    "ivorian diaspora": ("diaspora", "ivorian"),
    "ivorian emigrants": ("emigrants", "ivorian"),
    "ivorian expatriates": ("expatriates", "ivorian"),
    "japanese men wheelchair racers": ("men wheelchair racers", "japanese"),
    "japanese men's wheelchair basketball players": ("men's wheelchair basketball players", "japanese"),
    "japanese wheelchair basketball players": ("wheelchair basketball players", "japanese"),
    "japanese wheelchair curlers": ("wheelchair curlers", "japanese"),
    "japanese wheelchair racers": ("wheelchair racers", "japanese"),
    "japanese wheelchair rugby players": ("wheelchair rugby players", "japanese"),
    "japanese wheelchair tennis players": ("wheelchair tennis players", "japanese"),
    "japanese women wheelchair racers": ("women wheelchair racers", "japanese"),
    "kuwaiti men's wheelchair basketball players": ("men's wheelchair basketball players", "kuwaiti"),
    "kuwaiti wheelchair basketball players": ("wheelchair basketball players", "kuwaiti"),
    "kuwaiti wheelchair racers": ("wheelchair racers", "kuwaiti"),
    "latvian wheelchair curlers": ("wheelchair curlers", "latvian"),
    "lithuanian wheelchair racers": ("wheelchair racers", "lithuanian"),
    "macedonian wheelchair racers": ("wheelchair racers", "macedonian"),
    "mexican men wheelchair racers": ("men wheelchair racers", "mexican"),
    "mexican wheelchair racers": ("wheelchair racers", "mexican"),
    "mexican women wheelchair racers": ("women wheelchair racers", "mexican"),
    "moroccan competitors": ("competitors", "moroccan"),
    "moroccan male middle distance runners": ("male middle distance runners", "moroccan"),
    "moroccan male middle-distance runners": ("male middle-distance runners", "moroccan"),
    "north korean sport": ("sport", "north korean"),
    "north korean television": ("television", "north korean"),
    "northern ireland descent": ("descent", "northern ireland"),
    "norwegian figure skaters": ("figure skaters", "norwegian"),
    "norwegian male pair skaters": ("male pair skaters", "norwegian"),
    "norwegian male single skaters": ("male single skaters", "norwegian"),
    "norwegian pair skaters": ("pair skaters", "norwegian"),
    "norwegian short track speed skaters": ("short track speed skaters", "norwegian"),
    "norwegian wheelchair curlers": ("wheelchair curlers", "norwegian"),
    "norwegian wheelchair racers": ("wheelchair racers", "norwegian"),
    "omani football": ("football", "omani"),
    "pakistani psychiatrists": ("psychiatrists", "pakistani"),
    "peruvian television actors": ("television actors", "peruvian"),
    "philippine films": ("films", "philippine"),
    "polish businesspeople": ("businesspeople", "polish"),
    "polish wheelchair racers": ("wheelchair racers", "polish"),
    "polish women": ("women", "polish"),
    "portuguese healthcare managers": ("healthcare managers", "portuguese"),
    "puerto rican wheelchair sports competitors": ("wheelchair sports competitors", "puerto rican"),
    "puerto rican wheelchair track and field athletes": ("wheelchair track and field athletes", "puerto rican"),
    "puerto rican wheelchair track": ("wheelchair track", "puerto rican"),
    "republic-of ireland football managers": ("football managers", "republic-of ireland"),
    "russian folklore characters": ("folklore characters", "russian"),
    "russian wheelchair curlers": ("wheelchair curlers", "russian"),
    "russian wheelchair racers": ("wheelchair racers", "russian"),
    "sammarinese wheelchair racers": ("wheelchair racers", "sammarinese"),
    "scottish popular culture": ("popular culture", "scottish"),
    "scottish traditions": ("traditions", "scottish"),
    "scottish wheelchair curlers": ("wheelchair curlers", "scottish"),
    "scottish wheelchair curling champions": ("wheelchair curling champions", "scottish"),
    "scottish wheelchair racers": ("wheelchair racers", "scottish"),
    "scottish women wheelchair racers": ("women wheelchair racers", "scottish"),
    "slovak wheelchair curlers": ("wheelchair curlers", "slovak"),
    "south african men wheelchair racers": ("men wheelchair racers", "south african"),
    "south african wheelchair basketball players": ("wheelchair basketball players", "south african"),
    "south african wheelchair racers": ("wheelchair racers", "south african"),
    "south american pan africanists": ("pan africanists", "south american"),
    "south american pan-africanists": ("pan-africanists", "south american"),
    "south korean television series": ("television series", "south korean"),
    "south korean wheelchair curlers": ("wheelchair curlers", "south korean"),
    "south korean wheelchair racers": ("wheelchair racers", "south korean"),
    "spanish men's wheelchair basketball players": ("men's wheelchair basketball players", "spanish"),
    "spanish sports broadcasters": ("sports broadcasters", "spanish"),
    "spanish wheelchair basketball players": ("wheelchair basketball players", "spanish"),
    "spanish wheelchair fencers": ("wheelchair fencers", "spanish"),
    "spanish wheelchair racers": ("wheelchair racers", "spanish"),
    "spanish wheelchair tennis players": ("wheelchair tennis players", "spanish"),
    "swedish oncologists": ("oncologists", "swedish"),
    "swedish wheelchair curlers": ("wheelchair curlers", "swedish"),
    "swedish wheelchair curling champions": ("wheelchair curling champions", "swedish"),
    "swedish wheelchair racers": ("wheelchair racers", "swedish"),
    "swedish wheelchair tennis players": ("wheelchair tennis players", "swedish"),
    "swiss men wheelchair racers": ("men wheelchair racers", "swiss"),
    "swiss men's wheelchair basketball players": ("men's wheelchair basketball players", "swiss"),
    "swiss wheelchair basketball players": ("wheelchair basketball players", "swiss"),
    "swiss wheelchair curlers": ("wheelchair curlers", "swiss"),
    "swiss wheelchair curling champions": ("wheelchair curling champions", "swiss"),
    "swiss wheelchair curling championship": ("wheelchair curling championship", "swiss"),
    "swiss wheelchair racers": ("wheelchair racers", "swiss"),
    "swiss wheelchair tennis players": ("wheelchair tennis players", "swiss"),
    "swiss women wheelchair racers": ("women wheelchair racers", "swiss"),
    "thai wheelchair racers": ("wheelchair racers", "thai"),
    "thai wheelchair tennis players": ("wheelchair tennis players", "thai"),
    "tunisian wheelchair racers": ("wheelchair racers", "tunisian"),
    "turkish expatriate sports-people": ("expatriate sports-people", "turkish"),
    "turkish men's wheelchair basketball players": ("men's wheelchair basketball players", "turkish"),
    "turkish wheelchair basketball players": ("wheelchair basketball players", "turkish"),
    "turkish wheelchair racers": ("wheelchair racers", "turkish"),
    "turkish wheelchair tennis players": ("wheelchair tennis players", "turkish"),
    "turkish women wheelchair racers": ("women wheelchair racers", "turkish"),
    "turkish women's wheelchair basketball players": ("women's wheelchair basketball players", "turkish"),
    "ugandan football": ("football", "ugandan"),
    "welsh men wheelchair racers": ("men wheelchair racers", "welsh"),
    "welsh wheelchair curlers": ("wheelchair curlers", "welsh"),
    "welsh wheelchair racers": ("wheelchair racers", "welsh"),
    "welsh women wheelchair racers": ("women wheelchair racers", "welsh"),
    "yemeni football teams": ("football teams", "yemeni"),
    "yemeni national football team managers": ("national football team managers", "yemeni"),
    "yemeni national football team": ("national football team", "yemeni"),
    "yemeni national football teams": ("national football teams", "yemeni"),
    "yemeni national football": ("national football", "yemeni"),
    "yemeni national softball team managers": ("national softball team managers", "yemeni"),
    "yemeni national softball team": ("national softball team", "yemeni"),
    "yemeni national softball": ("national softball", "yemeni"),
    "yemeni shi'a muslims": ("shi'a muslims", "yemeni"),
    "zambian wheelchair racers": ("wheelchair racers", "zambian"),
}


@pytest.mark.parametrize("category, expected", data_nat.items(), ids=lambda x: x[0])
def test_nat(category: str, expected: tuple[str, str]) -> None:
    # Test with a valid category and nat
    result = get_suffix(category, "nat")
    assert result == expected



#!/usr/bin/python3
""" """

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.new_resolvers.sports_resolvers.raw_sports import find_jobs_bot, wrap_team_xo_normal_2025_with_ends

test_find_jobs_bot_data_with_additional = {
    "women's national youth association football teams": "منتخبات كرة قدم وطنية للشابات",
    "women's national ice hockey teams": "منتخبات هوكي جليد وطنية للسيدات",
    "national under-18 ice hockey teams": "منتخبات هوكي جليد وطنية تحت 18 سنة",
    "women's national under-18 ice hockey teams": "منتخبات هوكي جليد وطنية تحت 18 سنة للسيدات",
    "national youth women's football teams": "منتخبات كرة قدم وطنية للشابات",
    "american football leagues templates": "قوالب دوريات كرة قدم أمريكية",
    "national softball teams coaches": "مدربو منتخبات كرة لينة وطنية",
    "national under-15 football teams": "منتخبات كرة قدم وطنية تحت 15 سنة",
    "national under-18 football teams": "منتخبات كرة قدم وطنية تحت 18 سنة",
    "national under-19 basketball teams": "منتخبات كرة سلة وطنية تحت 19 سنة",
    "national under-20 basketball teams": "منتخبات كرة سلة وطنية تحت 20 سنة",
    "national under-21 field hockey teams": "منتخبات هوكي ميدان وطنية تحت 21 سنة",
    "national women's under-19 basketball teams": "منتخبات كرة سلة وطنية تحت 19 سنة للسيدات",
    "national women's under-20 football teams": "منتخبات كرة قدم وطنية تحت 20 سنة للسيدات",
    "national women's under-23 football teams": "منتخبات كرة قدم وطنية تحت 23 سنة للسيدات",
    "national youth women's under-14 softball leagues scouts": "كشافة دوريات كرة لينة وطنية تحت 14 سنة للشابات",
    "national youth women's under-14 softball leagues trainers": "مدربو دوريات كرة لينة وطنية تحت 14 سنة للشابات",
    "national youth women's under-14 softball leagues umpires": "حكام دوريات كرة لينة وطنية تحت 14 سنة للشابات",
    "national youth women's under-14 softball teams coaches": "مدربو منتخبات كرة لينة وطنية تحت 14 سنة للشابات",
    "national youth women's under-14 softball teams scouts": "كشافة منتخبات كرة لينة وطنية تحت 14 سنة للشابات",
    "national youth women's under-14 softball teams trainers": "مدربو منتخبات كرة لينة وطنية تحت 14 سنة للشابات",
    "rugby league teams": "فرق دوري رجبي",
    "rugby teams": "فرق رجبي",
    "under-13 baseball leagues films": "أفلام دوريات كرة قاعدة تحت 13 سنة",
    "under-13 baseball leagues finals": "نهائيات دوريات كرة قاعدة تحت 13 سنة",
    "under-13 baseball leagues positions": "مراكز دوريات كرة قاعدة تحت 13 سنة",
    "under-13 baseball leagues tournaments": "بطولات دوريات كرة قاعدة تحت 13 سنة",
    "under-13 baseball teams films": "أفلام فرق كرة قاعدة تحت 13 سنة",
    "under-13 baseball teams positions": "مراكز فرق كرة قاعدة تحت 13 سنة",
    "under-13 baseball teams tournaments": "بطولات فرق كرة قاعدة تحت 13 سنة",
    "wheelchair rugby league teams": "فرق دوري رجبي على كراسي متحركة",
    "wheelchair rugby teams": "فرق رجبي على كراسي متحركة",
}

test_find_jobs_bot_data_0 = {
    # "college football": "كرة قدم الكليات",
    "baseball competitions": "منافسات كرة قاعدة",
    "national football manager history": "تاريخ مدربو منتخبات كرة قدم وطنية",
    "national under-20 football manager history": "تاريخ مدربو منتخبات كرة قدم تحت 20 سنة",
    "swimming competitions": "منافسات سباحة",
}

test_find_jobs_bot_data = {
    "amateur wrestling": "مصارعة للهواة",
    "international women's wrestling competitions": "منافسات مصارعة دولية للسيدات",
    "international women's basketball competitions": "منافسات كرة سلة دولية للسيدات",
    "international women's cricket competitions": "منافسات كريكت دولية للسيدات",
    "international women's field hockey competitions": "منافسات هوكي ميدان دولية للسيدات",
    "international women's football competitions": "منافسات كرة قدم دولية للسيدات",
    "international men's wrestling competitions": "منافسات مصارعة دولية للرجال",
    "international men's football competitions": "منافسات كرة قدم دولية للرجال",
    "women's international basketball": "كرة سلة دولية للسيدات",
    "women's international football": "كرة قدم دولية للسيدات",
    "national women's equestrian manager history": "تاريخ مدربو منتخبات فروسية وطنية للسيدات",
    "domestic women's football leagues": "دوريات كرة قدم محلية للسيدات",
    "domestic women's handball leagues": "دوريات كرة يد محلية للسيدات",
    "women's international wrestling": "مصارعة دولية للسيدات",
    "national women's wrestling manager history": "تاريخ مدربو منتخبات مصارعة وطنية للسيدات",
    "international women's wrestling": "مصارعة دولية للسيدات",
    "domestic women's wrestling clubs": "أندية مصارعة محلية للسيدات",
    "domestic women's wrestling coaches": "مدربو مصارعة محلية للسيدات",
    "domestic women's wrestling competitions": "منافسات مصارعة محلية للسيدات",
    "domestic women's wrestling leagues": "دوريات مصارعة محلية للسيدات",
    "domestic women's wrestling cups": "كؤوس مصارعة محلية للسيدات",
    "national women's field hockey teams": "منتخبات هوكي ميدان وطنية نسائية",
    "national women's floorball teams": "منتخبات كرة أرض وطنية نسائية",
    "national women's rugby sevens teams": "منتخبات سباعيات رجبي وطنية نسائية",
    "national women's softball teams": "منتخبات كرة لينة وطنية نسائية",
    "national women's wheelchair basketball teams": "منتخبات كرة سلة على كراسي متحركة وطنية نسائية",
    "women's wrestling": "مصارعة نسائية",
    "women's wrestling teams": "فرق مصارعة نسائية",
    "national women's wrestling teams": "منتخبات مصارعة وطنية نسائية",
    "under-13 wrestling manager history": "تاريخ مدربو مصارعة تحت 13 سنة",
    "under-14 wrestling manager history": "تاريخ مدربو مصارعة تحت 14 سنة",
    "under-15 wrestling manager history": "تاريخ مدربو مصارعة تحت 15 سنة",
    "under-16 wrestling manager history": "تاريخ مدربو مصارعة تحت 16 سنة",
    "under-17 wrestling manager history": "تاريخ مدربو مصارعة تحت 17 سنة",
    "under-18 wrestling manager history": "تاريخ مدربو مصارعة تحت 18 سنة",
    "under-19 wrestling manager history": "تاريخ مدربو مصارعة تحت 19 سنة",
    "under-20 wrestling manager history": "تاريخ مدربو مصارعة تحت 20 سنة",
    "under-21 wrestling manager history": "تاريخ مدربو مصارعة تحت 21 سنة",
    "under-23 wrestling manager history": "تاريخ مدربو مصارعة تحت 23 سنة",
    "under-24 wrestling manager history": "تاريخ مدربو مصارعة تحت 24 سنة",
    "under-13 equestrian manager history": "تاريخ مدربو فروسية تحت 13 سنة",
    "under-14 equestrian manager history": "تاريخ مدربو فروسية تحت 14 سنة",
    "grand slam (wrestling) tournaments": "بطولات مصارعة كبرى",
    "professional wrestling cups": "كؤوس مصارعة محترفين",
    "professional wrestling competitions": "منافسات مصارعة محترفين",
    "professional wrestling leagues": "دوريات مصارعة محترفين",
    "defunct indoor wrestling cups": "كؤوس مصارعة داخل الصالات سابقة",
    "defunct outdoor wrestling cups": "كؤوس مصارعة في الهواء الطلق سابقة",
    "defunct wrestling cup competitions": "منافسات كؤوس مصارعة سابقة",
    "defunct wrestling cups": "كؤوس مصارعة سابقة",
    "domestic wrestling cup": "كؤوس مصارعة محلية",
    "domestic wrestling cups": "كؤوس مصارعة محلية",
    "wrestling cup competitions": "منافسات كؤوس مصارعة",
    "wrestling cups": "كؤوس مصارعة",
    "outdoor wrestling cups": "كؤوس مصارعة في الهواء الطلق",
    "indoor wrestling cups": "كؤوس مصارعة داخل الصالات",
    "amateur wrestling championships": "بطولات مصارعة للهواة",
    "current wrestling seasons": "مواسم مصارعة حالية",
    "defunct indoor wrestling clubs": "أندية مصارعة داخل الصالات سابقة",
    "defunct indoor wrestling coaches": "مدربو مصارعة داخل الصالات سابقة",
    "defunct indoor wrestling competitions": "منافسات مصارعة داخل الصالات سابقة",
    "defunct indoor wrestling leagues": "دوريات مصارعة داخل الصالات سابقة",
    "defunct outdoor wrestling clubs": "أندية مصارعة في الهواء الطلق سابقة",
    "defunct outdoor wrestling coaches": "مدربو مصارعة في الهواء الطلق سابقة",
    "defunct outdoor wrestling competitions": "منافسات مصارعة في الهواء الطلق سابقة",
    "defunct outdoor wrestling leagues": "دوريات مصارعة في الهواء الطلق سابقة",
    "defunct wrestling clubs": "أندية مصارعة سابقة",
    "defunct wrestling coaches": "مدربو مصارعة سابقة",
    "defunct wrestling competitions": "منافسات مصارعة سابقة",
    "defunct wrestling leagues": "دوريات مصارعة سابقة",
    "defunct wrestling teams": "فرق مصارعة سابقة",
    "domestic wrestling": "مصارعة محلية",
    "domestic wrestling clubs": "أندية مصارعة محلية",
    "domestic wrestling coaches": "مدربو مصارعة محلية",
    "domestic wrestling competitions": "منافسات مصارعة محلية",
    "domestic wrestling leagues": "دوريات مصارعة محلية",
    "fictional wrestling": "مصارعة خيالية",
    "fifth level wrestling league": "دوريات مصارعة من الدرجة الخامسة",
    "fifth level wrestling leagues": "دوريات مصارعة من الدرجة الخامسة",
    "fifth tier wrestling league": "دوريات مصارعة من الدرجة الخامسة",
    "fifth tier wrestling leagues": "دوريات مصارعة من الدرجة الخامسة",
    "first level wrestling league": "دوريات مصارعة من الدرجة الأولى",
    "first level wrestling leagues": "دوريات مصارعة من الدرجة الأولى",
    "first tier wrestling league": "دوريات مصارعة من الدرجة الأولى",
    "first tier wrestling leagues": "دوريات مصارعة من الدرجة الأولى",
    "first-class wrestling": "مصارعة من الدرجة الأولى",
    "first-class wrestling competitions": "منافسات مصارعة من الدرجة الأولى",
    "first-class wrestling matches": "مباريات مصارعة من الدرجة الأولى",
    "first-class wrestling teams": "فرق مصارعة من الدرجة الأولى",
    "fourth level wrestling league": "دوريات مصارعة من الدرجة الرابعة",
    "fourth level wrestling leagues": "دوريات مصارعة من الدرجة الرابعة",
    "fourth tier wrestling league": "دوريات مصارعة من الدرجة الرابعة",
    "fourth tier wrestling leagues": "دوريات مصارعة من الدرجة الرابعة",
    "grand slam (wrestling)": "بطولات مصارعة كبرى",
    "grand slam (wrestling) tournament champions": "أبطال بطولات مصارعة كبرى",
    "indoor wrestling": "مصارعة داخل الصالات",
    "indoor wrestling clubs": "أندية مصارعة داخل الصالات",
    "indoor wrestling coaches": "مدربو مصارعة داخل الصالات",
    "indoor wrestling competitions": "منافسات مصارعة داخل الصالات",
    "indoor wrestling leagues": "دوريات مصارعة داخل الصالات",
    "international men's wrestling": "مصارعة دولية للرجال",
    "international men's wrestling players": "لاعبو مصارعة دوليون",
    "international men's wrestling playerss": "لاعبو مصارعة دوليون",
    "international women's wrestling players": "لاعبات مصارعة دوليات",
    "international women's wrestling playerss": "لاعبات مصارعة دوليات",
    "international wrestling": "مصارعة دولية",
    "International wrestling competition tournaments": "بطولات منافسات مصارعة دولية",
    "International wrestling competitions": "منافسات مصارعة دولية",
    "international wrestling managers": "مدربو مصارعة دوليون",
    "international wrestling players": "لاعبو مصارعة دوليون",
    "international wrestling playerss": "لاعبو مصارعة دوليون",
    "International wrestling races": "سباقات مصارعة دولية",
    "International wrestling tournaments": "بطولات مصارعة دولية",
    "international youth wrestling competitions": "منافسات مصارعة شبابية دولية",
    "men's international wrestling": "مصارعة دولية للرجال",
    "men's international wrestling players": "لاعبو مصارعة دوليون",
    "men's international wrestling playerss": "لاعبو مصارعة دوليون",
    "men's wrestling": "مصارعة رجالية",
    "men's wrestling teams": "فرق مصارعة رجالية",
    "military wrestling": "مصارعة عسكرية",
    "military wrestling competitions": "منافسات مصارعة عسكرية",
    "multi-national wrestling championships": "بطولات مصارعة متعددة الجنسيات",
    "multi-national wrestling league": "دوريات مصارعة متعددة الجنسيات",
    "multi-national wrestling leagues": "دوريات مصارعة متعددة الجنسيات",
    "national a' wrestling teams": "منتخبات مصارعة للمحليين",
    "national a. wrestling teams": "منتخبات مصارعة للمحليين",
    "national b wrestling teams": "منتخبات مصارعة رديفة",
    "national b. wrestling teams": "منتخبات مصارعة رديفة",
    "national junior men's wrestling teams": "منتخبات مصارعة وطنية للناشئين",
    "national junior wrestling teams": "منتخبات مصارعة وطنية للناشئين",
    "national men's wrestling manager history": "تاريخ مدربو منتخبات مصارعة وطنية للرجال",
    "national men's wrestling teams": "منتخبات مصارعة وطنية رجالية",
    "national reserve wrestling teams": "منتخبات مصارعة وطنية احتياطية",
    "national under-13 wrestling manager history": "تاريخ مدربو منتخبات مصارعة تحت 13 سنة",
    "national under-14 wrestling manager history": "تاريخ مدربو منتخبات مصارعة تحت 14 سنة",
    "national under-15 wrestling manager history": "تاريخ مدربو منتخبات مصارعة تحت 15 سنة",
    "national under-16 wrestling manager history": "تاريخ مدربو منتخبات مصارعة تحت 16 سنة",
    "national under-17 wrestling manager history": "تاريخ مدربو منتخبات مصارعة تحت 17 سنة",
    "national under-18 wrestling manager history": "تاريخ مدربو منتخبات مصارعة تحت 18 سنة",
    "national under-19 wrestling manager history": "تاريخ مدربو منتخبات مصارعة تحت 19 سنة",
    "national under-20 wrestling manager history": "تاريخ مدربو منتخبات مصارعة تحت 20 سنة",
    "national under-21 wrestling manager history": "تاريخ مدربو منتخبات مصارعة تحت 21 سنة",
    "national under-23 wrestling manager history": "تاريخ مدربو منتخبات مصارعة تحت 23 سنة",
    "national under-24 wrestling manager history": "تاريخ مدربو منتخبات مصارعة تحت 24 سنة",
    "national wrestling champions": "أبطال بطولات مصارعة وطنية",
    "national wrestling championships": "بطولات مصارعة وطنية",
    "national wrestling league": "دوريات مصارعة وطنية",
    "national wrestling leagues": "دوريات مصارعة وطنية",
    "national wrestling manager history": "تاريخ مدربو منتخبات مصارعة وطنية",
    "national wrestling team results": "نتائج منتخبات مصارعة وطنية",
    "national wrestling teams": "منتخبات مصارعة وطنية",
    "national youth wrestling teams": "منتخبات مصارعة وطنية شبابية",
    "outdoor wrestling": "مصارعة في الهواء الطلق",
    "outdoor wrestling clubs": "أندية مصارعة في الهواء الطلق",
    "outdoor wrestling coaches": "مدربو مصارعة في الهواء الطلق",
    "outdoor wrestling competitions": "منافسات مصارعة في الهواء الطلق",
    "outdoor wrestling leagues": "دوريات مصارعة في الهواء الطلق",
    "premier wrestling league": "دوريات مصارعة من الدرجة الممتازة",
    "premier wrestling leagues": "دوريات مصارعة من الدرجة الممتازة",
    "reserve wrestling teams": "فرق مصارعة احتياطية",
    "second level wrestling league": "دوريات مصارعة من الدرجة الثانية",
    "second level wrestling leagues": "دوريات مصارعة من الدرجة الثانية",
    "second tier wrestling league": "دوريات مصارعة من الدرجة الثانية",
    "second tier wrestling leagues": "دوريات مصارعة من الدرجة الثانية",
    "seventh level wrestling league": "دوريات مصارعة من الدرجة السابعة",
    "seventh level wrestling leagues": "دوريات مصارعة من الدرجة السابعة",
    "seventh tier wrestling league": "دوريات مصارعة من الدرجة السابعة",
    "seventh tier wrestling leagues": "دوريات مصارعة من الدرجة السابعة",
    "sixth level wrestling league": "دوريات مصارعة من الدرجة السادسة",
    "sixth level wrestling leagues": "دوريات مصارعة من الدرجة السادسة",
    "sixth tier wrestling league": "دوريات مصارعة من الدرجة السادسة",
    "sixth tier wrestling leagues": "دوريات مصارعة من الدرجة السادسة",
    "third level wrestling league": "دوريات مصارعة من الدرجة الثالثة",
    "third level wrestling leagues": "دوريات مصارعة من الدرجة الثالثة",
    "third tier wrestling league": "دوريات مصارعة من الدرجة الثالثة",
    "third tier wrestling leagues": "دوريات مصارعة من الدرجة الثالثة",
    "top level wrestling league": "دوريات مصارعة من الدرجة الأولى",
    "top level wrestling leagues": "دوريات مصارعة من الدرجة الأولى",
    "under-13 wrestling": "مصارعة تحت 13 سنة",
    "under-14 wrestling": "مصارعة تحت 14 سنة",
    "under-15 wrestling": "مصارعة تحت 15 سنة",
    "under-16 wrestling": "مصارعة تحت 16 سنة",
    "under-17 wrestling": "مصارعة تحت 17 سنة",
    "under-18 wrestling": "مصارعة تحت 18 سنة",
    "under-19 wrestling": "مصارعة تحت 19 سنة",
    "under-20 wrestling": "مصارعة تحت 20 سنة",
    "under-21 wrestling": "مصارعة تحت 21 سنة",
    "under-23 wrestling": "مصارعة تحت 23 سنة",
    "under-24 wrestling": "مصارعة تحت 24 سنة",
    "women's international wrestling players": "لاعبات مصارعة دوليات",
    "women's international wrestling playerss": "لاعبات مصارعة دوليات",
    "wrestling chairmen and investors": "رؤساء ومسيرو مصارعة",
    "wrestling competitions": "منافسات مصارعة",
    "wrestling league competitions": "منافسات دوري مصارعة",
    "wrestling league teams": "فرق دوري مصارعة",
    "wrestling leagues": "دوريات مصارعة",
    "wrestling olympic bronze medalists": "ميداليات مصارعة برونزية أولمبية",
    "wrestling olympic gold medalists": "ميداليات مصارعة ذهبية أولمبية",
    "wrestling olympic silver medalists": "ميداليات مصارعة فضية أولمبية",
    "wrestling races": "سباقات مصارعة",
    "wrestling super leagues": "دوريات سوبر مصارعة",
    "youth international wrestling": "مصارعة دولية شبابية",
    "youth wrestling": "مصارعة شبابية",
    "youth wrestling competitions": "منافسات مصارعة شبابية",
    "national men's beach volleyball teams": "منتخبات كرة طائرة شاطئية وطنية رجالية",
    "national men's volleyball teams": "منتخبات كرة طائرة وطنية رجالية",
    "national men's wheelchair basketball teams": "منتخبات كرة سلة على كراسي متحركة وطنية رجالية",
    "basketball olympic bronze medalists": "ميداليات كرة سلة برونزية أولمبية",
    "current badminton seasons": "مواسم تنس ريشة حالية",
    "current cricket seasons": "مواسم كريكت حالية",
    "current football seasons": "مواسم كرة قدم حالية",
    "current hurling seasons": "مواسم قذف حالية",
    "cycling races": "سباقات سباق دراجات هوائية",
    "defunct american football teams": "فرق كرة قدم أمريكية سابقة",
    "defunct athletics clubs": "أندية ألعاب قوى سابقة",
    "defunct australian rules football clubs": "أندية كرة قدم أسترالية سابقة",
    "defunct baseball teams": "فرق كرة قاعدة سابقة",
    "defunct basketball leagues": "دوريات كرة سلة سابقة",
    "defunct basketball teams": "فرق كرة سلة سابقة",
    "defunct canadian football teams": "فرق كرة قدم كندية سابقة",
    "defunct cycling teams": "فرق سباق دراجات هوائية سابقة",
    "defunct football clubs": "أندية كرة قدم سابقة",
    "defunct football competitions": "منافسات كرة قدم سابقة",
    "defunct football leagues": "دوريات كرة قدم سابقة",
    "defunct handball clubs": "أندية كرة يد سابقة",
    "defunct handball competitions": "منافسات كرة يد سابقة",
    "defunct ice hockey leagues": "دوريات هوكي جليد سابقة",
    "defunct ice hockey teams": "فرق هوكي جليد سابقة",
    "defunct indoor american football leagues": "دوريات كرة قدم أمريكية داخل الصالات سابقة",
    "defunct lacrosse teams": "فرق لاكروس سابقة",
    "defunct rugby league teams": "فرق دوري رجبي سابقة",
    "defunct rugby union competitions": "منافسات اتحاد رجبي سابقة",
    "defunct soccer clubs": "أندية كرة قدم سابقة",
    "defunct speed skating clubs": "أندية تزلج سريع سابقة",
    "defunct sports clubs": "أندية رياضية سابقة",
    "defunct sports competitions": "منافسات رياضية سابقة",
    "defunct sports leagues": "دوريات رياضية سابقة",
    "defunct volleyball clubs": "أندية كرة طائرة سابقة",
    "domestic cricket competitions": "منافسات كريكت محلية",
    "domestic football leagues": "دوريات كرة قدم محلية",
    "domestic football": "كرة قدم محلية",
    "domestic handball leagues": "دوريات كرة يد محلية",
    "fictional motorsports": "رياضة محركات خيالية",
    "first-class cricket teams": "فرق كريكت من الدرجة الأولى",
    "first-class cricket": "كريكت من الدرجة الأولى",
    "football chairmen and investors": "رؤساء ومسيرو كرة قدم",
    "football league competitions": "منافسات دوري كرة قدم",
    "fourth level football leagues": "دوريات كرة قدم من الدرجة الرابعة",
    "indoor football": "كرة قدم داخل الصالات",
    "indoor hockey clubs": "أندية هوكي داخل الصالات",
    "indoor hockey": "هوكي داخل الصالات",
    "indoor soccer clubs": "أندية كرة قدم داخل الصالات",
    "indoor soccer coaches": "مدربو كرة قدم داخل الصالات",
    "indoor soccer": "كرة قدم داخل الصالات",
    "indoor track and field": "سباقات مضمار وميدان داخل الصالات",
    "international aquatics competitions": "منافسات رياضات مائية دولية",
    "international archery competitions": "منافسات نبالة دولية",
    "international athletics competitions": "منافسات ألعاب قوى دولية",
    "international bandy competitions": "منافسات باندي دولية",
    "international baseball competitions": "منافسات كرة قاعدة دولية",
    "international basketball competitions": "منافسات كرة سلة دولية",
    "international boxing competitions": "منافسات بوكسينغ دولية",
    "international chess competitions": "منافسات شطرنج دولية",
    "international cricket": "كريكت دولية",
    "international cricket competitions": "منافسات كريكت دولية",
    "international curling competitions": "منافسات كيرلنغ دولية",
    "international cycle races": "سباقات دراجات دولية",
    "international fencing competitions": "منافسات مبارزة سيف شيش دولية",
    "international field hockey competitions": "منافسات هوكي ميدان دولية",
    "international figure skating competitions": "منافسات تزلج فني دولية",
    "international football": "كرة قدم دولية",
    "international football competitions": "منافسات كرة قدم دولية",
    "international futsal competitions": "منافسات كرة صالات دولية",
    "international gymnastics competitions": "منافسات جمباز دولية",
    "international handball competitions": "منافسات كرة يد دولية",
    "international ice hockey competitions": "منافسات هوكي جليد دولية",
    "international kabaddi competitions": "منافسات كابادي دولية",
    "international netball competitions": "منافسات كرة شبكة دولية",
    "international roller hockey competitions": "منافسات هوكي دحرجة دولية",
    "international rugby league competitions": "منافسات دوري رجبي دولية",
    "international rugby sevens players": "لاعبو سباعيات رجبي دوليون",
    "international rugby union competitions": "منافسات اتحاد رجبي دولية",
    "international softball competitions": "منافسات كرة لينة دولية",
    "international taekwondo competitions": "منافسات تايكوندو دولية",
    "international track and field competitions": "منافسات سباقات مضمار وميدان دولية",
    "international volleyball competitions": "منافسات كرة طائرة دولية",
    "international water polo competitions": "منافسات كرة ماء دولية",
    "international weightlifting competitions": "منافسات رفع أثقال دولية",
    "international wrestling competitions": "منافسات مصارعة دولية",
    "international youth basketball competitions": "منافسات كرة سلة شبابية دولية",
    "international youth football competitions": "منافسات كرة قدم شبابية دولية",
    "men's international basketball": "كرة سلة دولية للرجال",
    "men's international football": "كرة قدم دولية للرجال",
    "military diving": "غطس عسكرية",
    "military football": "كرة قدم عسكرية",
    "national b football teams": "منتخبات كرة قدم رديفة",
    "national badminton teams": "منتخبات تنس ريشة وطنية",
    "national bobsleigh teams": "منتخبات زلاجة جماعية وطنية",
    "national equestrian manager history": "تاريخ مدربو منتخبات فروسية وطنية",
    "national football team results": "نتائج منتخبات كرة قدم وطنية",
    "national ice hockey teams": "منتخبات هوكي جليد وطنية",
    "national junior men's handball teams": "منتخبات كرة يد وطنية للناشئين",
    "national men's equestrian manager history": "تاريخ مدربو منتخبات فروسية وطنية للرجال",
    "national rowing championships": "بطولات تجديف وطنية",
    "national rugby sevens teams": "منتخبات سباعيات رجبي وطنية",
    "national softball teams": "منتخبات كرة لينة وطنية",
    "national speed skating championships": "بطولات تزلج سريع وطنية",
    "national tennis league": "دوريات كرة مضرب وطنية",
    "national under-13 equestrian manager history": "تاريخ مدربو منتخبات فروسية تحت 13 سنة",
    "national under-14 equestrian manager history": "تاريخ مدربو منتخبات فروسية تحت 14 سنة",
    "national wheelchair basketball teams": "منتخبات كرة سلة على كراسي متحركة وطنية",
    "national wheelchair handball teams": "منتخبات كرة يد على كراسي متحركة وطنية",
    "national wheelchair rugby teams": "منتخبات رجبي على كراسي متحركة وطنية",
    "outdoor equestrian": "فروسية في الهواء الطلق",
    "premier badminton league": "دوريات تنس ريشة من الدرجة الممتازة",
    "premier volleyball league": "دوريات كرة طائرة من الدرجة الممتازة",
    "professional ice hockey leagues": "دوريات هوكي جليد للمحترفين",
    "professional soccer leagues": "دوريات كرة قدم للمحترفين",
    "professional sports leagues": "دوريات رياضية للمحترفين",
    "rugby competitions": "منافسات رجبي",
    "rugby league competitions": "منافسات دوري رجبي",
    "softball competitions": "منافسات كرة لينة",
    "under-13 equestrian": "فروسية تحت 13 سنة",
    "under-14 equestrian": "فروسية تحت 14 سنة",
    "under-17 football": "كرة قدم تحت 17 سنة",
    "under-18 ice hockey": "هوكي جليد تحت 18 سنة",
    "under-18 rugby union": "اتحاد رجبي تحت 18 سنة",
    "under-20 basketball": "كرة سلة تحت 20 سنة",
    "wheelchair rugby competitions": "منافسات رجبي على كراسي متحركة",
    "wheelchair rugby league competitions": "منافسات دوري رجبي على كراسي متحركة",
    "youth international football": "كرة قدم دولية شبابية",
}


def wrap_callback(category: str) -> str:
    return wrap_team_xo_normal_2025_with_ends(category, callback=find_jobs_bot)


@pytest.mark.parametrize("category, expected", test_find_jobs_bot_data.items(), ids=test_find_jobs_bot_data.keys())
@pytest.mark.fast
def test_Get_New_team_xo_data(category: str, expected: str) -> None:
    label1 = wrap_callback(category)
    assert isinstance(label1, str)
    assert label1 == expected


@pytest.mark.parametrize("category, expected", test_find_jobs_bot_data_0.items(), ids=test_find_jobs_bot_data_0.keys())
@pytest.mark.fast
def test_test_find_jobs_bot_data_0(category: str, expected: str) -> None:
    label1 = wrap_callback(category)
    assert isinstance(label1, str)
    assert label1 == expected


TEMPORAL_CASES = [
    ("test_find_jobs_bot", test_find_jobs_bot_data, wrap_callback),
    # ("test_find_jobs_bot_with_additional", test_find_jobs_bot_data_with_additional, wrap_callback),
]


@pytest.mark.parametrize("name,data,callback", TEMPORAL_CASES)
@pytest.mark.dump
def test_all_dump(name: str, data: dict[str, str], callback) -> None:
    expected, diff_result = one_dump_test(data, callback)
    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



import re
from typing import Dict

import pytest

from ArWikiCats.translations import SPORTS_KEYS_FOR_JOBS
from ArWikiCats.translations_formats import FormatData

# --- Fixtures ---------------------------------------------------------


@pytest.fixture(scope="session")
def formatted_data() -> Dict[str, str]:
    return {
        "{sport}": "{sport_label}",
        "amateur {sport}": "{sport_label} للهواة",
        "mens youth {sport}": "{sport_label} للشباب",
        "mens {sport}": "{sport_label} رجالية",
        "womens youth {sport}": "{sport_label} للشابات",
        "womens {sport}": "{sport_label} نسائية",
        "youth {sport}": "{sport_label} شبابية",
    }


@pytest.fixture(scope="session")
def data_list() -> Dict[str, str]:
    return SPORTS_KEYS_FOR_JOBS


@pytest.fixture
def bot(formatted_data: Dict[str, str], data_list: Dict[str, str]) -> FormatData:
    return FormatData(formatted_data, data_list, key_placeholder="{sport}", value_placeholder="{sport_label}")


# --- keys_to_pattern --------------------------------------------------
def test_keys_to_pattern_returns_regex(bot: FormatData) -> None:
    pattern = bot.keys_to_pattern()
    assert isinstance(pattern, re.Pattern)
    assert pattern.search("football")
    assert pattern.search("rugby union")


def test_keys_to_pattern_empty() -> None:
    bot_empty = FormatData({}, {})
    assert bot_empty.keys_to_pattern() is None
    assert bot_empty.pattern is None


# --- match_key --------------------------------------------------------
@pytest.mark.parametrize(
    "category,expected",
    [
        ("men's football players", "football"),
        ("women's basketball coaches", "basketball"),
        ("youth snooker records", "snooker"),
        ("rugby league World Cup", "rugby league"),
        ("wheelchair rugby league World Cup", "wheelchair rugby league"),
        ("rugby league World Cup", "rugby league"),
        ("unknown sport category", ""),
    ],
)
def test_match_key(bot: FormatData, category: str, expected: str) -> None:
    result = bot.match_key(category)
    assert result == expected


def test_match_key_no_pattern() -> None:
    bot = FormatData({}, {})
    assert bot.match_key("football") == ""


# --- normalize_category -----------------------------------------------
@pytest.mark.parametrize(
    "category,sport_key,expected",
    [
        ("men's football players", "football", "men's {sport} players"),
        ("youth snooker records", "snooker", "youth {sport} records"),
    ],
)
def test_normalize_category(bot: FormatData, category: str, sport_key: str, expected: str) -> None:
    normalized = bot.normalize_category(category, sport_key)
    assert normalized == expected


def test_get_template_not_found(bot: FormatData) -> None:
    label = bot.get_template("football", "unrelated term")
    assert label == ""


# --- apply_pattern_replacement ----------------------------------------
@pytest.mark.parametrize(
    "template_label,sport_label,expected",
    [
        ("بطولة xoxo العالمية", "كرة القدم", "بطولة كرة القدم العالمية"),
        ("xoxo مدربون", "كرة السلة", "كرة السلة مدربون"),
        ("بدون متغير", "كرة اليد", "بدون متغير"),  # placeholder missing
    ],
)
def test_apply_pattern_replacement(bot: FormatData, template_label: str, sport_label: str, expected: str) -> None:
    bot.value_placeholder = "xoxo"
    result = bot.apply_pattern_replacement(template_label, sport_label)
    assert result == expected


@pytest.mark.parametrize(
    "category",
    [
        "unknown sport",
        "غير معروف",
    ],
)
def test_search_invalid(bot: FormatData, category: str) -> None:
    assert bot.search(category) == ""


# --- search edge cases -----------------------------------------------
def test_search_missing_sport_label(formatted_data: Dict[str, str], data_list: Dict[str, str]) -> None:
    # remove a key intentionally
    temp = dict(data_list)
    del temp["football"]
    bot = FormatData(formatted_data, temp)
    assert bot.search("men's football players") == ""


def test_search_missing_template_label(formatted_data: Dict[str, str], data_list: Dict[str, str]) -> None:
    bot = FormatData({}, data_list)
    assert bot.search("men's football players") == ""



"""Comprehensive pytest suite for move_years module."""

import pytest

from ArWikiCats.fix.mv_years import move_by_in, move_years, move_years_first


@pytest.mark.parametrize(
    "text,expected",
    [
        # --- Simple year movement ---
        ("1989 في اتحاد الرجبي", "اتحاد الرجبي في 1989"),
        ("2020 في كرة القدم", "كرة القدم في 2020"),
        ("2010–11 في الموسيقى", "الموسيقى في 2010–11"),
        ("200 قبل الميلاد في الإمبراطورية الرومانية", "الإمبراطورية الرومانية في 200 قبل الميلاد"),
        ("2019 في الأفلام", "2019 في الأفلام"),  # skip_it case
        ("الأفلام في 2019", "الأفلام في 2019"),  # already correct
        # --- No match ---
        ("اتحاد الرجبي 1989", "اتحاد الرجبي 1989"),
        ("القرن العشرين في أوروبا", "القرن العشرين في أوروبا"),
        # --- With 'حسب' clause ---
        ("1989 في اتحاد الرجبي حسب البلد", "اتحاد الرجبي في 1989 حسب البلد"),
        ("2020 في الرياضة حسب النوع", "الرياضة في 2020 حسب النوع"),
        # --- BCE variants ---
        ("200 ق.م في مصر", "مصر في 200 ق م"),
        ("عقد 1990 في الفنون", "الفنون في عقد 1990"),
    ],
    ids=lambda val: None if isinstance(val, tuple) else f"case_{hash(val) % 10000}",
)
def test_move_years_first_o(text: str, expected: str) -> None:
    """Test move_years_first for all expected patterns."""
    assert move_years_first(text) == expected


@pytest.mark.parametrize(
    "text,expected",
    [
        # --- Simple reorder with 'حسب' clause ---
        ("اتحاد الرجبي حسب البلد في 1989", "اتحاد الرجبي في 1989 حسب البلد"),
        ("كرة القدم حسب الموسم في 2020", "كرة القدم في 2020 حسب الموسم"),
        # --- BCE and century variants ---
        ("المعارك حسب المنطقة في 300 ق.م", "المعارك في 300 ق م حسب المنطقة"),
        ("الممالك حسب الحكم في القرن 19", "الممالك في القرن 19 حسب الحكم"),
        # --- With underscores ---
        ("اتحاد_الرجبي_حسب_البلد_في_1989", "اتحاد الرجبي في 1989 حسب البلد"),
        # --- No match ---
        ("اتحاد الرجبي في 1989 حسب البلد", "اتحاد الرجبي في 1989 حسب البلد"),
    ],
    ids=lambda val: None if isinstance(val, tuple) else f"case_{hash(val) % 10000}",
)
def test_move_by_in(text: str, expected: str) -> None:
    """Test move_by_in for year and century reordering."""
    assert move_by_in(text) == expected


@pytest.mark.parametrize(
    "text,expected",
    [
        # --- Category namespace handling ---
        ("تصنيف:1989 في اتحاد الرجبي", "تصنيف:اتحاد الرجبي في 1989"),
        ("تصنيف:اتحاد الرجبي حسب البلد في 1989", "تصنيف:اتحاد الرجبي في 1989 حسب البلد"),
        # --- BCE handling inside category ---
        ("تصنيف:200 ق.م في مصر", "تصنيف:مصر في 200 ق م"),
        # --- When already normalized ---
        ("تصنيف:اتحاد الرجبي في 1989", "تصنيف:اتحاد الرجبي في 1989"),
        ("تصنيف:الموسيقى في 2010–11", "تصنيف:الموسيقى في 2010–11"),
        # --- Fallback from first to by_in ---
        ("تصنيف:كرة القدم حسب الموسم في 2020", "تصنيف:كرة القدم في 2020 حسب الموسم"),
    ],
    ids=lambda val: None if isinstance(val, tuple) else f"case_{hash(val) % 10000}",
)
def test_move_years_with_category_namespace(text: str, expected: str) -> None:
    """Test category namespace preservation."""
    assert move_years(text) == expected


@pytest.mark.parametrize(
    "text,expected",
    [
        # --- Simple text ---
        ("1989 في اتحاد الرجبي", "اتحاد الرجبي في 1989"),
        ("اتحاد الرجبي حسب البلد في 1989", "اتحاد الرجبي في 1989 حسب البلد"),
        # --- No match cases ---
        ("القرن 20 في أوروبا", "أوروبا في القرن 20"),
        ("تصنيف:الأفلام في 2019", "تصنيف:الأفلام في 2019"),
        # --- Complex BCE and underscore ---
        ("تصنيف:200 ق.م في الإمبراطورية_الرومانية", "تصنيف:الإمبراطورية الرومانية في 200 ق م"),
    ],
    ids=lambda val: None if isinstance(val, tuple) else f"case_{hash(val) % 10000}",
)
def test_move_years_combined(text: str, expected: str) -> None:
    """Full integration tests combining both functions."""
    assert move_years(text) == expected


@pytest.mark.parametrize(
    "text",
    [
        "random text with no match",
        "تصنيف:random text",
        "اتحاد الرجبي فقط",
        "في 2020 فقط",
        "حسب الموسم فقط",
    ],
    ids=lambda val: None if isinstance(val, tuple) else f"case_{hash(val) % 10000}",
)
def test_no_modifications(text) -> None:
    """Ensure unrelated strings remain unchanged."""
    assert move_years(text) == text



"""

This module provides functionality to translate category titles
that follow a 'country-year' pattern. It uses a pre-configured
bot (`yc_bot`) to handle the translation logic.
"""

import functools

from ..helps import logger
from ..translations import COUNTRY_LABEL_OVERRIDES, US_STATES, all_country_ar
from ..translations_formats import MultiDataFormatterBaseYear, format_year_country_data
from .categories_patterns.COUNTRY_YEAR import COUNTRY_YEAR_DATA

# TODO: update countries_data with COUNTRY_LABEL_OVERRIDES after check any issues!


@functools.lru_cache(maxsize=1)
def load_bot() -> MultiDataFormatterBaseYear:
    countries_data = all_country_ar | US_STATES

    return format_year_country_data(
        formatted_data=COUNTRY_YEAR_DATA,
        data_list=countries_data,
        key_placeholder="{country1}",
        value_placeholder="{country1}",
        key2_placeholder="{year1}",
        value2_placeholder="{year1}",
        text_after="",
        text_before="the ",
    )


@functools.lru_cache(maxsize=10000)
def resolve_country_time_pattern(category: str) -> str:
    logger.debug(f"<<yellow>> start resolve_country_time_pattern: {category=}")

    yc_bot = load_bot()
    result = yc_bot.search_all_category(category)

    logger.info_if_or_debug(f"<<yellow>> end resolve_country_time_pattern: {category=}, {result=}", result)
    return result or ""


__all__ = [
    "resolve_country_time_pattern",
    "load_bot",
]



#
import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_arabic_category_label

pan_arican = {
    "Category:Members of the Pan-African Parliament": "تصنيف:أعضاء البرلمان الإفريقي",
    "Category:Members of the Pan-African Parliament from Algeria": "تصنيف:أعضاء البرلمان الإفريقي من الجزائر",
    "Category:Members of the Pan-African Parliament from Angola": "تصنيف:أعضاء البرلمان الإفريقي من أنغولا",
    "Category:Members of the Pan-African Parliament from Benin": "تصنيف:أعضاء البرلمان الإفريقي من بنين",
    "Category:Members of the Pan-African Parliament from Botswana": "تصنيف:أعضاء البرلمان الإفريقي من بوتسوانا",
    "Category:Members of the Pan-African Parliament from Burkina Faso": "تصنيف:أعضاء البرلمان الإفريقي من بوركينا فاسو",
    "Category:Members of the Pan-African Parliament from Burundi": "تصنيف:أعضاء البرلمان الإفريقي من بوروندي",
    "Category:Members of the Pan-African Parliament from Cameroon": "تصنيف:أعضاء البرلمان الإفريقي من الكاميرون",
    "Category:Members of the Pan-African Parliament from Cape Verde": "تصنيف:أعضاء البرلمان الإفريقي من الرأس الأخضر",
    "Category:Members of the Pan-African Parliament from Chad": "تصنيف:أعضاء البرلمان الإفريقي من تشاد",
    "Category:Members of the Pan-African Parliament from Djibouti": "تصنيف:أعضاء البرلمان الإفريقي من جيبوتي",
    "Category:Members of the Pan-African Parliament from Egypt": "تصنيف:أعضاء البرلمان الإفريقي من مصر",
    "Category:Members of the Pan-African Parliament from Equatorial Guinea": "تصنيف:أعضاء البرلمان الإفريقي من غينيا الاستوائية",
    "Category:Members of the Pan-African Parliament from Eswatini": "تصنيف:أعضاء البرلمان الإفريقي من إسواتيني",
    "Category:Members of the Pan-African Parliament from Gabon": "تصنيف:أعضاء البرلمان الإفريقي من الغابون",
    "Category:Members of the Pan-African Parliament from Ghana": "تصنيف:أعضاء البرلمان الإفريقي من غانا",
    "Category:Members of the Pan-African Parliament from Lesotho": "تصنيف:أعضاء البرلمان الإفريقي من ليسوتو",
    "Category:Members of the Pan-African Parliament from Libya": "تصنيف:أعضاء البرلمان الإفريقي من ليبيا",
    "Category:Members of the Pan-African Parliament from Mali": "تصنيف:أعضاء البرلمان الإفريقي من مالي",
    "Category:Members of the Pan-African Parliament from Mozambique": "تصنيف:أعضاء البرلمان الإفريقي من موزمبيق",
    "Category:Members of the Pan-African Parliament from Namibia": "تصنيف:أعضاء البرلمان الإفريقي من ناميبيا",
    "Category:Members of the Pan-African Parliament from Niger": "تصنيف:أعضاء البرلمان الإفريقي من النيجر",
    "Category:Members of the Pan-African Parliament from Nigeria": "تصنيف:أعضاء البرلمان الإفريقي من نيجيريا",
    "Category:Members of the Pan-African Parliament from Rwanda": "تصنيف:أعضاء البرلمان الإفريقي من رواندا",
    "Category:Members of the Pan-African Parliament from Senegal": "تصنيف:أعضاء البرلمان الإفريقي من السنغال",
    "Category:Members of the Pan-African Parliament from Sierra Leone": "تصنيف:أعضاء البرلمان الإفريقي من سيراليون",
    "Category:Members of the Pan-African Parliament from South Africa": "تصنيف:أعضاء البرلمان الإفريقي من جنوب إفريقيا",
    "Category:Members of the Pan-African Parliament from South Sudan": "تصنيف:أعضاء البرلمان الإفريقي من جنوب السودان",
    "Category:Members of the Pan-African Parliament from Sudan": "تصنيف:أعضاء البرلمان الإفريقي من السودان",
    "Category:Members of the Pan-African Parliament from Tanzania": "تصنيف:أعضاء البرلمان الإفريقي من تنزانيا",
    "Category:Members of the Pan-African Parliament from the Central African Republic": "تصنيف:أعضاء البرلمان الإفريقي من جمهورية إفريقيا الوسطى",
    "Category:Members of the Pan-African Parliament from the Gambia": "تصنيف:أعضاء البرلمان الإفريقي من غامبيا",
    "Category:Members of the Pan-African Parliament from republic of congo": "تصنيف:أعضاء البرلمان الإفريقي من جمهورية الكونغو",
    "Category:Members of the Pan-African Parliament from the Sahrawi Arab Democratic Republic": "تصنيف:أعضاء البرلمان الإفريقي من الجمهورية العربية الصحراوية الديمقراطية",
    "Category:Members of the Pan-African Parliament from Togo": "تصنيف:أعضاء البرلمان الإفريقي من توغو",
    "Category:Members of the Pan-African Parliament from Tunisia": "تصنيف:أعضاء البرلمان الإفريقي من تونس",
    "Category:Members of the Pan-African Parliament from Uganda": "تصنيف:أعضاء البرلمان الإفريقي من أوغندا",
    "Category:Members of the Pan-African Parliament from Zambia": "تصنيف:أعضاء البرلمان الإفريقي من زامبيا",
    "Category:Members of the Pan-African Parliament from Zimbabwe": "تصنيف:أعضاء البرلمان الإفريقي من زيمبابوي",
}


@pytest.mark.dump
def test_pan_arican() -> None:
    expected, diff_result = one_dump_test(pan_arican, resolve_arabic_category_label)

    dump_diff(diff_result, "test_pan_arican")
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(pan_arican):,}"


@pytest.mark.parametrize("category, expected", pan_arican.items(), ids=pan_arican.keys())
@pytest.mark.slow
def test_pan_arican_dump(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected



""" """

from typing import Any, Dict, Tuple


def get_from_starts_dict(category3: str, data: Dict[str, Dict[str, Any]]) -> Tuple[str, str]:
    """Strip matching prefixes from ``category3`` based on provided patterns."""
    list_of_cat = ""

    category3_original = category3

    try:
        sorted_data = sorted(
            data.items(),
            key=lambda k: (-k[0].count(" "), -len(k[0])),
        )
    except AttributeError:
        sorted_data = data.items()

    for key, tab in sorted_data:
        # precise removal
        remove_key = tab.get("remove", key)
        if category3_original.startswith(remove_key):
            list_of_cat = tab["lab"]

            category3 = category3_original[len(remove_key) :]  # .lstrip()

            break

    return category3, list_of_cat


def get_from_endswith_dict(category3: str, data: Dict[str, Dict[str, Any]]) -> Tuple[str, str]:
    """Strip matching suffixes from ``category3`` based on provided patterns."""
    list_of_cat = ""

    category3_original = category3

    try:
        sorted_data = sorted(
            data.items(),
            key=lambda k: (-k[0].count(" "), -len(k[0])),
        )
    except AttributeError:
        sorted_data = data.items()

    for key, tab in sorted_data:
        if category3_original.endswith(key):
            list_of_cat = tab["lab"]

            # precise removal
            remove_key = tab.get("remove", key)

            category3 = category3_original[: -len(remove_key)]  # .strip()

            break

    return category3, list_of_cat



"""Mappings for club-related categories and miscellaneous concepts."""

from __future__ import annotations

from typing import Tuple

from ...helps import len_print
from ..utils.json_dir import open_json_file

New_male_keys = {
    "agricultural science": "علم زراعي",
    "agricultural union": "اتحاد زراعي",
    "anarchist fiction": "خيال لاسلطوي",
    "arts fiction": "خيال فني",
    "arts science": "علم فني",
    "astronomical union": "اتحاد فلكي",
    "chemical science": "علم كيميائي",
    "christian broadcasting": "بث لاسلكي مسيحي",
    "christian fiction": "خيال مسيحي",
    "christian riots": "شغب مسيحي",
    "christian science": "علم مسيحي",
    "christian union": "اتحاد مسيحي",
    "christian violence": "عنف مسيحي",
    "commercial union": "اتحاد تجاري",
    "constitutional union": "اتحاد دستوري",
    "cultural exchange": "تبادل ثقافي",
    "cultural impact": "أثر ثقافي",
    "economic impact": "أثر اقتصادي",
    "economic union": "اتحاد اقتصادي",
    "educational broadcasting": "بث لاسلكي تعليمي",
    "environmental fiction": "خيال بيئي",
    "environmental impact": "أثر بيئي",
    "environmental science": "علم بيئي",
    "government science": "علم حكومي",
    "industrial union": "اتحاد صناعي",
    "legislative violence": "عنف تشريعي",
    "maritime broadcasting": "بث لاسلكي بحري",
    "medical fiction": "خيال طبي",
    "medical food": "طعام طبي",
    "medical science": "علم طبي",
    "military broadcasting": "بث لاسلكي عسكري",
    "military fiction": "خيال عسكري",
    "military food": "طعام عسكري",
    "military medicine": "طب عسكري",
    "military science": "علم عسكري",
    "military union": "اتحاد عسكري",
    "naval medicine": "طب عسكرية بحري",
    "political fiction": "خيال سياسي",
    "political orientation": "توجه سياسي",
    "political repression": "قمع سياسي",
    "political riots": "شغب سياسي",
    "political science": "علم سياسي",
    "political union": "اتحاد سياسي",
    "political violence": "عنف سياسي",
    "religious broadcasting": "بث لاسلكي ديني",
    "religious fiction": "خيال ديني",
    "religious food": "طعام ديني",
    "religious riots": "شغب ديني",
    "religious science": "علم ديني",
    "religious violence": "عنف ديني",
    "student exchange": "تبادل طلابي",
    "student riots": "شغب طلابي",
    "student science": "علم طلابي",
    "youth science": "علم شبابي",
}

BASE_POP_FINAL_5: dict[str, str] = {
    "trustees of": "أمناء",
    "members of": "أعضاء",
    "independent members": "أعضاء مستقلون",
    "members": "أعضاء",
    "secession": "الانفصالية",
    "separatism": "الانفصالية",
    "military of": "عسكرية",
    "tanks of": "دبابات",
    "relationships": "علاقات",
    "mass media": "وسائل الإعلام",
    "denominations": "طوائف",
    "equipment of": "معدات",
    "radars of": "رادارات",
    "cargo ships of": "سفن بضائع",
    "ships of": "سفن",
    "satellites of": "أقمار صناعية تتبع",
    "military aviation": "طيران عسكري",
    "wind farms": "مزارع الرياح",
    "aviation": "طيران",
    "equipment": "معدات",
    "military-equipment of": "عتاد عسكري",
    "military equipment of": "عتاد عسكري",
    "barracks": "ثكنات",
    "deuterostomes": "ثانويات الفم",
    "order of gold star (ukraine)": "وسام النجمة الذهبية الأوكراني",
    "order of the holy sepulchre": "فرسان القبر المقدس",
    "behistun inscription": "نقش بيستون",
    "macaronic language": "تلميع",
    "binding energy": "طاقة الارتباط",
    "dumping (pricing policy)": "إغراق تجاري",
    "cosmopolitanism": "كوسموبوليتية",
    "lakshmi": "لاكشمي",
    "medical privacy": "خصوصية صحية",
    "kinetic energy": "طاقة حركية",
    "prohibition": "منع الكحول",
    "chemnitz": "كيمنتس",
    "glucose": "غلوكوز",
    "weimar": "فايمار",
    "kempten": "كمبتن",
    "bottrop": "بوتروب",
    "greifswald": "غرايفسفالت",
    "schweinfurt": "شفاينفورت",
    "wilhelmshaven": "فيلهلمسهافن",
    "hof, bavaria": "هوف",
    "wolfsburg": "فولفسبورغ",
    "baden-baden": "بادن بادن",
    "patriotism": "وطنية",
    "memmingen": "ميمينجين",
    "rostock": "روستوك",
    "salzgitter": "زالتسغيتر",
    "zwickau": "تسفيكاو",
    "dortmund": "دورتموند",
    "ingolstadt": "إنغولشتات",
    "rosenheim": "روزنهايم",
    "economic indicators": "مؤشرات اقتصادية",
    "scientific skepticism": "شكوكية علمية",
    "tropes": "مجازات",
    "theism": "الإيمان بالله",
    "chemical energy": "طاقة كيميائية",
    "fictional characters": "شخصيات خيالية",
    "economic systems": "أنظمة اقتصادية",
    "platonism": "أفلاطونية",
    "electric power": "طاقة كهربائية",
    "fifa": "فيفا",
    "determinism": "حتمية",
    "european system of central banks": "النظام الأوروبي للبنوك المركزية",
    "homeostasis": "استتباب",
    "irony": "سخرية",
    "rationalism": "عقلانية",
    "plot (narrative)": "حبكة (سرد)",
    "injection (medicine)": "حقن طبي",
    "ointments": "مراهم",
    "cardiac arrhythmia": "اضطراب النظم القلبي",
    "economic bubbles": "فقاعات اقتصادية",
    "euphemisms": "تسميل",
    "onomatopoeia": "محاكاة صوتية",
    "synecdoche": "مجاز مرسل",
    "flora of azerbaijan": "نباتات أذربيجان",
    "oligopoly": "احتكار القلة",
    "aphorisms": "حكمة",
    "dehydration": "تجفاف",
    "traffic management": "إدارة الحركة",
    "walking": "مشي",
    "types of soil": "أنواع التربة",
    "gnosticism": "غنوصية",
    "humanism": "إنسانية",
    "dresden": "درسدن",
    "metonymy": "كناية",
    "monopoly (economics)": "احتكار",
    "monopoly": "الاحتكار",
    "prayer": "صلاة",
    "tübingen": "توبينغن",
    "leipzig": "لايبزيغ",
    "nuclear power": "طاقة نووية",
    "bonn": "بون",
    "wiesbaden": "فيسبادن",
    "kassel": "كاسل",
    "communism": "شيوعية",
    "gera": "غيرا",
    "plauen": "بلاوين",
    "religious fundamentalism": "أصولية دينية",
    "mannheim": "مانهايم",
    "lüneburg": "لونبورغ",
    "eisenach": "أيسناخ",
    "death": "موت",
    "do it yourself": "افعلها بنفسك",
    "duisburg": "دويسبورغ",
    "erfurt": "إرفورت",
    "bamberg": "بامبرغ",
    "bochum": "بوخوم",
    "darmstadt": "دارمشتات",
    "göttingen": "غوتنغن",
    "offenbach am main": "أوفنباخ أم ماين",
    "karlsruhe": "كارلسروه",
    "heilbronn": "هايلبرون",
    "force": "قوى",
    "pforzheim": "بفورتسهايم",
    "atheism": "إلحاد",
    "osnabrück": "أوسنابروك",
    "schwerin": "شفيرين",
    "materialism": "مادية",
    "bremerhaven": "بريمرهافن",
    "würzburg": "فورتسبورغ",
    "erlangen": "إرلنغن",
    "fables": "حكاية رمزية",
    "fürth": "فورت",
    "idealism": "مثالية",
    "jena": "يينا",
    "regensburg": "ريغنسبورغ",
    "global warming": "احترار عالمي",
    "ulm": "أولم",
    "amberg": "آمبرغ",
    "metaphors": "استعارات",
}

RESOURCE_LABELS: dict[str, str] = {
    "bauxite": "البوكسيت",
    "coal gas-fired power stations": "محطات توليد الطاقة تعمل بغاز الفحم",
    "coal": "الفحم",
    "coal-fired power stations": "محطات توليد الطاقة تعمل بالفحم",
    "computer companies": "شركات حوسبة",
    "copper": "النحاس",
    "dragon boat": "قوارب التنين",
    "electric power generation": "توليد الكهرباء",
    "electric power transmission": "نقل الكهرباء",
    "electric power": "القدرة الكهربائية",
    "electricity sector": "قطاع الكهرباء",
    "former power stations": "محطات طاقة سابقة",
    "fossil fuel": "وقود أحفوري",
    "fossil fuels": "وقود أحفوري",
    "gas-fired power plants": "محطات طاقة وقود أحفوري",
    "gold": "الذهب",
    "hydraulic fracturing": "تصديع مائي",
    "hydroelectric power stations": "محطات طاقة كهرمائية",
    "hydroelectricity": "الطاقة الكهرومائية",
    "hydroelectrics": "كهرمائية",
    "industries": "صناعات",
    "influence (social and political)": "تأثير اجتماعي وسياسي",
    "man-made disasters": "كوارث من صنع الإنسان",
    "mines": "مناجم",
    "mining": "التعدين",
    "natural gas fields": "خطوط غاز طبيعي",
    "natural gas pipelines": "خطوط أنابيب غاز",
    "natural gas": "غاز طبيعي",
    "natural gas-fired power stations": "محطات توليد الطاقة تعمل بالغاز الطبيعي",
    "nuclear power stations": "محطات طاقة نووية",
    "nuclear power": "طاقة نووية",
    "nuclear weapons testing": "اختبار الأسلحة النووية",
    "oil and gas": "النفط والغاز",
    "oil fields": "حقول نفط",
    "oil shale": "صخر زيتي",
    "oil shale-fired power stations": "محطات توليد الطاقة تعمل بالصخر الزيتي",
    "oil": "نفط",
    "oil-fired power stations": "محطات توليد الطاقة تعمل بزيت الوقود",
    "peat-fired power stations": "محطات توليد الطاقة تعمل بالخث",
    "petroleum": "بترول",
    "photovoltaic power stations": "محطات طاقة كهروضوئية",
    "photovoltaics": "خلايا كهروضوئية",
    "pollution": "تلوث",
    "power (social and political)": "نفوذ اجتماعي وسياسي",
    "power companies": "شركات طاقة",
    "power stations": "محطات طاقة",
    "proposed power stations": "محطات طاقة مقترحة",
    "sedimentary rocks": "صخور رسوبية",
    "service industries": "صناعات خدمية",
    "shipping": "النقل البحري",
    "solar eclipses": "كسوفات شمسية",
    "solar power stations": "محطات طاقة شمسية",
    "solar power": "طاقة شمسية",
    "solid fuel": "وقود صلب",
    "solid fuels": "وقود صلب",
    "trucking": "النقل بالشاحنات",
    "water resource management in": "إدارة الموارد المائية في",
    "water transportation": "النقل المائي",
    "wind power": "طاقة الرياح",
}


def build_pop_final_5() -> Tuple[dict[str, str], dict[str, str]]:
    """Build the club and miscellaneous concept mappings."""

    registry = dict(BASE_POP_FINAL_5)
    clubs = open_json_file("sports/Clubs_key.json") or {}

    clubs_index: dict[str, str] = {}
    for club, label in clubs.items():
        if not club or not label:
            continue
        club_lower = club.lower()
        registry[club_lower] = label
        clubs_index[club_lower] = label

    for key, label in RESOURCE_LABELS.items():
        registry[key.lower()] = label

    # registry.update(New_male_keys)
    return registry, clubs_index


pop_final_5, Clubs_key_2 = build_pop_final_5()

__all__ = ["pop_final_5", "Clubs_key_2"]

len_print.data_len(
    "all_keys5.py",
    {
        "pop_final_5": pop_final_5,
        "Clubs_key_2": Clubs_key_2,
    },
)



#!/usr/bin/python3
"""
Resolve geo names categories translations
NOTE: planned to replace pop_format in format_bots/__init__.py
"""
import functools
from typing import Dict

from ...helps import logger
from ...translations import COUNTRY_LABEL_OVERRIDES, raw_region_overrides
from ...translations_formats import FormatData, MultiDataFormatterBase
from .countries_names_data import formatted_data_en_ar_only

formatted_data_updated = dict(formatted_data_en_ar_only)

geo_keys: Dict[str, str] = {
    "sanaa": "صنعاء",
    "manitoba": "مانيتوبا",
    "bologna": "بولونيا",
    "hubei": "خوبي",
    "west virginia": "فرجينيا الغربية",
}

geo_data: Dict[str, str] = COUNTRY_LABEL_OVERRIDES | raw_region_overrides | geo_keys


@functools.lru_cache(maxsize=1)
def _load_bot() -> MultiDataFormatterBase:
    return FormatData(
        formatted_data_updated,
        geo_data,
        key_placeholder="{en}",
        value_placeholder="{ar}",
        text_before="the ",
        regex_filter=r"[\w-]",
    )


@functools.lru_cache(maxsize=10000)
def resolve_by_geo_names(category: str) -> str:
    logger.debug(f"<<yellow>> start resolve_by_geo_names: {category=}")

    nat_bot = _load_bot()
    result = nat_bot.search_all_category(category)

    logger.info_if_or_debug(f"<<yellow>> end resolve_by_geo_names: {category=}, {result=}", result)
    return result


__all__ = [
    "resolve_by_geo_names",
]



#
import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_arabic_category_label

geography_us_1 = {
    "Category:Louisiana": "تصنيف:لويزيانا",
    "Category:Maine": "تصنيف:مين",
    "Category:Kansas": "تصنيف:كانساس",
    "Category:Kentucky": "تصنيف:كنتاكي",
    "Category:Indiana": "تصنيف:إنديانا",
    "Category:Iowa": "تصنيف:آيوا",
    "Category:Idaho": "تصنيف:أيداهو",
    "Category:Illinois": "تصنيف:إلينوي",
    "Category:Georgia (U.S. state)": "تصنيف:ولاية جورجيا",
    "Category:Hawaii": "تصنيف:هاواي",
    "Category:Florida": "تصنيف:فلوريدا",
    "Category:Delaware": "تصنيف:ديلاوير",
    "Category:Connecticut": "تصنيف:كونيتيكت",
    "Category:Colorado": "تصنيف:كولورادو",
    "Category:California": "تصنيف:كاليفورنيا",
    "Category:Alabama": "تصنيف:ألاباما",
    "Category:Alaska": "تصنيف:ألاسكا",
    "Category:Arizona": "تصنيف:أريزونا",
}

geography_us_2 = {
    "Category:Missouri": "تصنيف:ميزوري",
    "Category:Nebraska": "تصنيف:نبراسكا",
    "Category:Nevada": "تصنيف:نيفادا",
    "Category:New Hampshire": "تصنيف:نيوهامشير",
    "Category:New Jersey": "تصنيف:نيوجيرسي",
    "Category:New Mexico": "تصنيف:نيومكسيكو",
    "Category:New York (state)": "تصنيف:ولاية نيويورك",
    "Category:North Carolina": "تصنيف:كارولاينا الشمالية",
    "Category:North Dakota": "تصنيف:داكوتا الشمالية",
    "Category:Nuclear power by country": "تصنيف:طاقة نووية حسب البلد",
    "Category:Ohio": "تصنيف:أوهايو",
    "Category:Oklahoma": "تصنيف:أوكلاهوما",
    "Category:Pennsylvania": "تصنيف:بنسلفانيا",
    "Category:Oregon": "تصنيف:أوريغن",
    "Category:Utah": "تصنيف:يوتا",
    "Category:Vermont": "تصنيف:فيرمونت",
    "Category:Virginia": "تصنيف:فرجينيا",
    "Category:Washington (state)": "تصنيف:ولاية واشنطن",
}

geography_us_3 = {
    "Category:Wyoming": "تصنيف:وايومنغ",
    "Category:West Virginia": "تصنيف:فرجينيا الغربية",
    "Category:Texas": "تصنيف:تكساس",
    "Category:Tennessee": "تصنيف:تينيسي",
    "Category:South Carolina": "تصنيف:كارولاينا الجنوبية",
    "Category:Rhode Island": "تصنيف:رود آيلاند",
    "Category:South Dakota": "تصنيف:داكوتا الجنوبية",
    "Category:Wisconsin": "تصنيف:ويسكونسن",
    "Category:Arkansas": "تصنيف:أركنساس",
    "Category:Maryland": "تصنيف:ماريلند",
    "Category:Massachusetts": "تصنيف:ماساتشوستس",
    "Category:Michigan": "تصنيف:ميشيغان",
    "Category:Minnesota": "تصنيف:منيسوتا",
    "Category:Mississippi": "تصنيف:مسيسيبي",
    "Category:Montana": "تصنيف:مونتانا",
}

test_data = [
    ("test_geography_us_1", geography_us_1),
    ("test_geography_us_2", geography_us_2),
    ("test_geography_us_3", geography_us_3),
]


@pytest.mark.parametrize("category, expected", geography_us_1.items(), ids=geography_us_1.keys())
@pytest.mark.fast
def test_geography_us_1(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", geography_us_2.items(), ids=geography_us_2.keys())
@pytest.mark.fast
def test_geography_us_2(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", geography_us_3.items(), ids=geography_us_3.keys())
@pytest.mark.fast
def test_geography_us_3(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("name,data", test_data)
@pytest.mark.dump
def test_geography_us(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



#!/usr/bin/python3
"""

from ..matables_bots.check_bot import check_key_new_players
check_key_new_players(key)
"""

from ...helps import logger
from ...translations import Jobs_new, jobs_mens_data
from ...utils import check_key_in_tables
from .bot import players_new_keys

set_tables = [players_new_keys, Jobs_new, jobs_mens_data]


def check_key_new_players_n(key: str) -> bool:
    """Return True if the key exists in any player or job mapping table."""
    return check_key_in_tables(key, set_tables) or check_key_in_tables(key.lower(), set_tables)


def check_key_new_players(key: str) -> bool:
    """Return True if the key exists in any player or job mapping table."""
    key_lower = key.lower()
    result = any(key in table or key_lower in table for table in set_tables)
    logger.info(f"check_key_new_players [{key}] == {result}")
    return result


def add_key_new_players(key: str, value: str, file: str) -> None:
    players_new_keys[key.lower()] = value
    logger.info(f"add to New_players[{key}] = {value} in {file}")



#!/usr/bin/python3
"""
Module for dictionary-based category translation formatting (Version 2).

This module provides FormatDataV2 and MultiDataFormatterBaseV2 classes for
advanced category translations where the data_list values can be dictionaries
with multiple placeholder replacements instead of simple strings.

Classes:
    FormatDataV2: Handles dictionary-based template-driven category translations.
    MultiDataFormatterBaseV2: Combines two FormatDataV2 instances for complex translations.

Example:
    >>> from ArWikiCats.translations_formats.DataModel import FormatDataV2
    >>> formatted_data = {
    ...     "{country} people": "{demonym} أشخاص",
    ... }
    >>> data_list = {
    ...     "yemen": {"demonym": "يمنيون", "country_ar": "اليمن"},
    ...     "egypt": {"demonym": "مصريون", "country_ar": "مصر"},
    ... }
    >>> bot = FormatDataV2(formatted_data, data_list, key_placeholder="{country}")
    >>> bot.search("yemen people")
    'يمنيون أشخاص'
"""

import re
from typing import Dict, Union

from ..formats_logger import logger
from .model_data_base import FormatDataBase
from .model_multi_data_base import MultiDataFormatterBaseHelpers


class FormatDataV2(FormatDataBase):
    """
    Handles dictionary-based template-driven category translations.

    This class extends FormatDataBase to support data_list values that are
    dictionaries containing multiple placeholders. This allows for more
    complex translations where multiple parts of the template need to be
    replaced with different values from the same key's data.

    Attributes:
        formatted_data (Dict[str, str]): Template patterns mapping English patterns to Arabic templates.
        data_list (Dict[str, Union[str, Dict[str, str]]]): Key mappings where values can be
            simple strings or dictionaries with multiple placeholder values.
        key_placeholder (str): Placeholder used in formatted_data keys.
        text_after (str): Optional text that appears after the key in patterns.
        text_before (str): Optional text that appears before the key in patterns.

    Example:
        >>> bot = FormatDataV2(
        ...     formatted_data={"{country} writers": "{demonym} كتاب"},
        ...     data_list={"yemen": {"demonym": "يمنيون"}},
        ...     key_placeholder="{country}",
        ... )
        >>> bot.search("yemen writers")
        'يمنيون كتاب'
    """

    def __init__(
        self,
        formatted_data: Dict[str, str],
        data_list: Dict[str, Union[str, Dict[str, str]]],
        key_placeholder: str = "xoxo",
        text_after: str = "",
        text_before: str = "",
        regex_filter: str = "",
        **kwargs,
    ) -> None:
        """Prepare helpers for matching and formatting template-driven labels."""
        super().__init__(
            formatted_data=formatted_data,
            data_list=data_list,
            key_placeholder=key_placeholder,
            text_after=text_after,
            text_before=text_before,
            regex_filter=regex_filter,
        )
        self.alternation: str = self.create_alternation()
        self.pattern = self.keys_to_pattern()

    def apply_pattern_replacement(self, template_label: str, sport_label: Union[str, Dict[str, str]]) -> str:
        """Replace value placeholder once template is chosen."""
        if not isinstance(sport_label, dict):
            return template_label

        final_label = template_label

        if isinstance(sport_label, dict):
            for key, val in sport_label.items():
                if isinstance(val, str) and val:
                    final_label = final_label.replace(f"{{{key}}}", val)

        # if any(f"{key}" in final_label for key in sport_label.keys()):
        #     logger.warning(f"Not all placeholders replaced in {final_label=}, {sport_label=}")
        #     # If not all placeholders were replaced, we can choose to either
        #     # leave the label as is or apply some default behavior.
        #     # For now, we'll just log a warning and return the label.
        #     return ""

        return final_label.strip()

    def replace_value_placeholder(self, label: str, value: Union[str, Dict[str, str]]) -> str:
        """
        Used in MultiDataFormatterBaseV2 / MultiDataFormatterBaseHelpers
        """
        if not isinstance(value, dict):
            return label

        final_label = label
        for key, val in value.items():
            if isinstance(val, str) and val:
                final_label = final_label.replace(f"{{{key}}}", val)

        # if any(f"{key}" in final_label for key in value.keys()):
        #     logger.warning(f"Not all placeholders replaced in {final_label=}, {value=}")
        #     # If not all placeholders were replaced, we can choose to either
        #     # leave the label as is or apply some default behavior.
        #     # For now, we'll just log a warning and return the label.
        #     return ""

        return final_label


class MultiDataFormatterBaseV2(MultiDataFormatterBaseHelpers):
    """
    Combines two FormatDataV2 instances for complex category translations.

    This class orchestrates two FormatDataV2 formatter instances to handle
    categories that contain two dynamic elements (e.g., nationality and
    profession). It inherits from MultiDataFormatterBaseHelpers to provide
    the core translation logic.

    Attributes:
        country_bot (FormatDataV2): Formatter for the first dynamic element (e.g., nationality).
        other_bot (FormatDataV2): Formatter for the second dynamic element (e.g., profession).
        search_first_part (bool): If True, search using only the first part after normalization.
        data_to_find (Dict[str, str] | None): Optional direct lookup dictionary for category labels.

    Example:
        >>> bot = MultiDataFormatterBaseV2(country_bot, profession_bot)
        >>> bot.create_label("yemeni writers")
        'كتاب يمنيون'
    """

    def __init__(
        self,
        country_bot: FormatDataV2,
        other_bot: FormatDataV2,
        search_first_part: bool = False,
        data_to_find: Dict[str, str] | None = None,
    ) -> None:
        """Prepare helpers for matching and formatting template-driven labels."""

        self.search_first_part = search_first_part
        self.country_bot = country_bot
        self.other_bot = other_bot
        self.data_to_find = data_to_find



#!/usr/bin/python3
"""Integration tests"""

import pytest

from ArWikiCats.translations_formats import FormatData

sample_data_type = tuple[dict[str, str], dict[str, str]]


@pytest.fixture
def sample_data() -> sample_data_type:
    formatted_data = {
        "{nat} cup": "كأس {nat}",
    }

    data_list = {
        "yemeni": "اليمن",
    }

    return formatted_data, data_list


def test_text_after(sample_data: sample_data_type) -> None:
    formatted_data, data_list = sample_data

    bot = FormatData(
        formatted_data,
        data_list,
        key_placeholder="{nat}",
        value_placeholder="{nat}",
        text_after=" people",
    )
    key = bot.match_key("yemeni cup")
    assert key == "yemeni"

    result = bot.search("yemeni cup")
    assert result == "كأس اليمن"

    normalize = bot.normalize_category("yemeni people cup", "yemeni")
    assert normalize == "{nat} cup"

    result2 = bot.search("yemeni people cup")
    assert result2 == "كأس اليمن"


def test_text_before(sample_data: sample_data_type) -> None:
    formatted_data, data_list = sample_data

    bot = FormatData(formatted_data, data_list, key_placeholder="{nat}", value_placeholder="{nat}", text_before="the ")

    result3 = bot.search("the yemeni cup")
    assert result3 == "كأس اليمن"

    normalize2 = bot.normalize_category("the yemeni cup", "yemeni")
    assert normalize2 == "{nat} cup"


def test_text_before_text_after(sample_data: sample_data_type) -> None:
    formatted_data, data_list = sample_data

    bot = FormatData(
        formatted_data,
        data_list,
        key_placeholder="{nat}",
        value_placeholder="{nat}",
        text_after=" people",
        text_before="the ",
    )

    normalize2 = bot.normalize_category("the yemeni people cup", "yemeni")
    assert normalize2 == "{nat} cup"

    result4 = bot.search("the yemeni people cup")
    assert result4 == "كأس اليمن"



"""Convenience exports for geographic translation tables."""

from .Cities import (
    CITY_TRANSLATIONS_LOWER,
)
from .labels_country import (
    COUNTRY_LABEL_OVERRIDES,
    US_STATES,
)
from .us_counties import (
    US_COUNTY_TRANSLATIONS,
    USA_PARTY_DERIVED_KEYS,
)

__all__ = [
    "CITY_TRANSLATIONS_LOWER",
    "US_COUNTY_TRANSLATIONS",
    "USA_PARTY_DERIVED_KEYS",
    "US_STATES",
    "COUNTRY_LABEL_OVERRIDES",
]



#
import pytest
from load_one_data import dump_diff, dump_same_and_not_same, one_dump_test

from ArWikiCats import resolve_arabic_category_label

data_not_ready = {
    "Category:20th century members of maine legislature": "تصنيف:أعضاء هيئة مين التشريعية في القرن 20",
    "Category:Wheelchair basketball at the Summer Paralympics navigational boxes": "تصنيف:صناديق تصفح كرة السلة على الكراسي المتحركة في الألعاب البارالمبية الصيفية",
    "Category:Wheelchair fencing at the Summer Paralympics navigational boxes": "تصنيف:صناديق تصفح مبارزة سيف الشيش على الكراسي المتحركة في الألعاب البارالمبية الصيفية",
    "Category:Wheelchair tennis at the Summer Paralympics navigational boxes": "تصنيف:صناديق تصفح كرة المضرب على الكراسي المتحركة في الألعاب البارالمبية الصيفية",
    "Category:Athletics at the Universiade navigational boxes": "تصنيف:صناديق تصفح ألعاب القوى في الألعاب الجامعية",
    "Category:Athletics at the Summer Universiade navigational boxes": "تصنيف:صناديق تصفح ألعاب القوى في الألعاب الجامعية الصيفية",
    "Category:Nations at multi-sport events navigational boxes": "تصنيف:صناديق تصفح بلدان في الأحداث الرياضية المتعددة",
    "Category:American Civil War by state navigational boxes": "تصنيف:صناديق تصفح الحرب الأهلية الأمريكية حسب الولاية",
    "Category:Canadian football teams": "تصنيف:فرق كرة القدم الكندية",
    "Category:Canadian football people": "تصنيف:أعلام كرة القدم الكندية",
    "Category:Canadian football leagues": "تصنيف:دوريات كرة القدم الكندية",
    "Category:1880s in film by country": "تصنيف:أفلام في عقد 1880 حسب البلد",
    "Category:Canadian football on television": "تصنيف:كرة القدم الكندية على التلفاز",
    "Category:18th-century people of the Dutch Empire": "تصنيف:أشخاص من الإمبراطورية الهولندية القرن 18",
    "Category:20th-century presidents of Russia": "تصنيف:رؤساء روسيا القرن 20",
    "Category:Attacks on diplomatic missions of Russia": "تصنيف:هجمات على بعثات دبلوماسية روسيا",
    "Category:waba champions cup": "تصنيف:كأس دوري غرب آسيا لكرة السلة",
    "Category:Italian defectors to the Soviet Union": "تصنيف:إيطاليون منشقون إلى الاتحاد السوفيتي",
    "Category:Lists of organisations based in Papua New Guinea": "تصنيف:قوائم منظمات مقرها في بابوا غينيا الجديدة",
    "Category:COVID-19 pandemic in Papua New Guinea templates": "تصنيف:قوالب جائحة فيروس كورونا في بابوا غينيا الجديدة",
    "Category:20th-century executions by Papua New Guinea": "تصنيف:إعدامات في بابوا غينيا الجديدة في القرن 20",
    "Category:Works by Antigua and Barbuda people": "تصنيف:أعمال أنتيغويون وبربوديون",
}

data1 = {
    "category:lists of american non-fiction television series episodes": "تصنيف:قوائم حلقات مسلسلات تلفزيونية غير خيالية أمريكية",
    "category:lists of australian non-fiction television series episodes": "تصنيف:قوائم حلقات مسلسلات تلفزيونية غير خيالية أسترالية",
    "category:lists of british non-fiction television series episodes": "تصنيف:قوائم حلقات مسلسلات تلفزيونية غير خيالية بريطانية",
    "category:lists of canadian non-fiction television series episodes": "تصنيف:قوائم حلقات مسلسلات تلفزيونية غير خيالية كندية",
    "category:lists of non-fiction television series episodes": "تصنيف:قوائم حلقات مسلسلات تلفزيونية غير خيالية",
    "Category:20th century synagogues in switzerland": "تصنيف:كنس في سويسرا في القرن 20",
    "Category:20th century prime ministers of japan": "تصنيف:رؤساء وزراء اليابان في القرن 20",
    "Category:2010–11 in Antigua and Barbuda football": "تصنيف:كرة القدم الأنتيغوية والبربودية في 2010–11",
    "Category:2011–12 in Antigua and Barbuda football": "تصنيف:كرة القدم الأنتيغوية والبربودية في 2011–12",
    "Category:2012–13 in Antigua and Barbuda football": "تصنيف:كرة القدم الأنتيغوية والبربودية في 2012–13",
    "Category:2013–14 in Antigua and Barbuda football": "تصنيف:كرة القدم الأنتيغوية والبربودية في 2013–14",
    "Category:2014–15 in Antigua and Barbuda football": "تصنيف:كرة القدم الأنتيغوية والبربودية في 2014–15",
    "Category:2015–16 in Antigua and Barbuda football": "تصنيف:كرة القدم الأنتيغوية والبربودية في 2015–16",
    "Category:2016–17 in Antigua and Barbuda football": "تصنيف:كرة القدم الأنتيغوية والبربودية في 2016–17",
    "Category:2017–18 in Antigua and Barbuda football": "تصنيف:كرة القدم الأنتيغوية والبربودية في 2017–18",
    "Category:2018–19 in Antigua and Barbuda football": "تصنيف:كرة القدم الأنتيغوية والبربودية في 2018–19",
    "Category:2019–20 in Antigua and Barbuda football": "تصنيف:كرة القدم الأنتيغوية والبربودية في 2019–20",
}

data2 = {
    "Category:Lists of Antigua and Barbuda people": "تصنيف:قوائم أنتيغويون وبربوديون",
    "Category:Antigua and Barbuda football templates": "تصنيف:قوالب كرة القدم الأنتيغوية والبربودية",
    "Category:10th century chinese people by occupation": "تصنيف:صينيون في القرن 10 حسب المهنة",
    "Category:15th century swiss people by occupation": "تصنيف:سويسريون في القرن 15 حسب المهنة",
    "Category:16th century iranian people by occupation": "تصنيف:إيرانيون في القرن 16 حسب المهنة",
    "Category:20th century croatian people by occupation": "تصنيف:كروات في القرن 20 حسب المهنة",
    "Category:21st century yemeni people by occupation": "تصنيف:يمنيون في القرن 21 حسب المهنة",
    "Category:3rd century asian people by nationality": "تصنيف:آسيويون في القرن 3 حسب الجنسية",
    "Category:20th century american people by occupation": "تصنيف:أمريكيون في القرن 20 حسب المهنة",
}

data3 = {
    "Category:2021 Tamil-language television series endings": "تصنيف:x",
    "Category:2024–2026 ICC Cricket World Cup League 2": "تصنيف:x",
    "Category:2026 All Elite Wrestling pay-per-view events": "تصنيف:x",
    "Category:2026 All-Ireland Senior Football Championship": "تصنيف:x",
    "Category:2026 animated television series debuts": "تصنيف:x",
    "Category:2026 anime television series debuts": "تصنيف:x",
    "Category:2026 anime": "تصنيف:x",
    "Category:2026 beauty pageants": "تصنيف:x",
    "Category:2026 Canadian Football League season by team": "تصنيف:x",
    "Category:2026 CONCACAF Champions Cup participants seasons": "تصنيف:x",
    "Category:2026 CONCACAF Champions Cup": "تصنيف:x",
    "Category:2026 concert residencies": "تصنيف:x",
    "Category:2026 concert tours": "تصنيف:x",
    "Category:2026 debut works": "تصنيف:x",
    "Category:2026 directorial debut films": "تصنيف:x",
    "Category:2026 English local elections": "تصنيف:x",
    "Category:2026 FIA World Endurance Championship season": "تصنيف:x",
    "Category:2026 FIBA 3x3 World Cup": "تصنيف:x",
    "Category:2026 FIFA World Cup qualification (CONCACAF)": "تصنيف:x",
    "Category:2026 FIFA World Cup qualification (UEFA)": "تصنيف:x",
    "Category:2026 FIFA World Cup qualification templates": "تصنيف:x",
    "Category:2026 IIHF Men's World Ice Hockey Championships": "تصنيف:x",
    "Category:2026 IIHF U18 Women's World Championships": "تصنيف:x",
    "Category:2026 in 3x3 basketball": "تصنيف:x",
    "Category:2026 in Asian international football": "تصنيف:x",
    "Category:2026 in Asian men's football": "تصنيف:x",
    "Category:2026 in Asian men's international football": "تصنيف:x",
    "Category:2026 in Asian women's international football": "تصنيف:x",
    "Category:2026 in Asian youth football": "تصنيف:x",
    "Category:2026 in Catalan sport": "تصنيف:x",
    "Category:2026 in computing": "تصنيف:x",
    "Category:2026 in disability sport": "تصنيف:x",
    "Category:2026 in European international football": "تصنيف:x",
    "Category:2026 in European men's football": "تصنيف:x",
    "Category:2026 in European men's international football": "تصنيف:x",
    "Category:2026 in European women's international football": "تصنيف:x",
    "Category:2026 in European youth football": "تصنيف:x",
    "Category:2026 in Formula Three": "تصنيف:x",
    "Category:2026 in Ladies' Gaelic football": "تصنيف:x",
    "Category:2026 in LGBTQ history": "تصنيف:x",
    "Category:2026 in men's international sport": "تصنيف:x",
    "Category:2026 in New Zealand cricket": "تصنيف:x",
    "Category:2026 in North Macedonia sport": "تصنيف:x",
    "Category:2026 in OFC football": "تصنيف:x",
    "Category:2026 in ski mountaineering": "تصنيف:x",
    "Category:2026 in speedway": "تصنيف:x",
    "Category:2026 in strength athletics": "تصنيف:x",
    "Category:2026 in the sport of athletics": "تصنيف:x",
    "Category:2026 in track racing": "تصنيف:x",
    "Category:2026 in UFC": "تصنيف:x",
    "Category:2026 in West Indian cricket": "تصنيف:x",
    "Category:2026 in women's international sport": "تصنيف:x",
    "Category:2026 London Borough council elections": "تصنيف:x",
    "Category:2026 Major League Baseball season": "تصنيف:x",
    "Category:2026 Men's FIH Hockey World Cup qualification": "تصنيف:x",
    "Category:2026 Men's FIH Hockey World Cup Qualifying Tournaments": "تصنيف:x",
    "Category:2026 Men's FIH Hockey World Cup": "تصنيف:x",
    "Category:2026 Men's T20 World Cup qualification": "تصنيف:x",
    "Category:2026 Men's T20 World Cup templates": "تصنيف:x",
    "Category:2026 Men's T20 World Cup": "تصنيف:x",
    "Category:2026 multiplayer online battle arena tournaments": "تصنيف:x",
    "Category:2026 National Football League (Ireland)": "تصنيف:x",
    "Category:2026 NFL season": "تصنيف:x",
    "Category:2026 Ontario municipal elections": "تصنيف:x",
    "Category:2026 political party leadership elections": "تصنيف:x",
    "Category:2026 song contests": "تصنيف:x",
    "Category:2026 Speedway Grand Prix": "تصنيف:x",
    "Category:2026 State Assembly elections in India": "تصنيف:x",
    "Category:2026 state constitutional officer elections in the United States": "تصنيف:x",
    "Category:2026 state legislature special elections in the United States": "تصنيف:x",
    "Category:2026 television specials": "تصنيف:x",
    "Category:2026 U.S. legislative sessions": "تصنيف:x",
    "Category:2026 UEFA European Under-17 Championship": "تصنيف:x",
    "Category:2026 UEFA European Under-19 Championship": "تصنيف:x",
    "Category:2026 Under-19 Men's Cricket World Cup": "تصنيف:x",
    "Category:2026 United Kingdom local elections": "تصنيف:x",
    "Category:2026 United States county executive elections": "تصنيف:x",
    "Category:2026 United States judicial elections": "تصنيف:x",
    "Category:2026 United States lieutenant gubernatorial elections": "تصنيف:x",
    "Category:2026 United States local elections": "تصنيف:x",
    "Category:2026 United States mayoral elections": "تصنيف:x",
    "Category:2026 United States state attorney general elections": "تصنيف:x",
    "Category:2026 United States state auditor elections": "تصنيف:x",
    "Category:2026 United States state secretary of state elections": "تصنيف:x",
    "Category:2026 United States state superintendent of public instruction elections": "تصنيف:x",
    "Category:2026 United States state treasurer elections": "تصنيف:x",
    "Category:2026 WAFF Championship": "تصنيف:x",
    "Category:2026 Women's FIH Hockey World Cup qualification": "تصنيف:x",
    "Category:2026 Women's FIH Hockey World Cup Qualifying Tournaments": "تصنيف:x",
    "Category:2026 Women's FIH Hockey World Cup": "تصنيف:x",
    "Category:2026 Women's T20 World Cup qualification": "تصنيف:x",
    "Category:2026 Women's T20 World Cup templates": "تصنيف:x",
    "Category:2026 Women's T20 World Cup": "تصنيف:x",
    "Category:2026 World Rally Championship season": "تصنيف:x",
    "Category:2026 WWE Network events": "تصنيف:x",
    "Category:2026 WWE pay-per-view events": "تصنيف:x",
    "Category:2026–27 Australian cricket season": "تصنيف:x",
    "Category:2026–27 in European international football": "تصنيف:x",
    "Category:2026–27 in European men's field hockey": "تصنيف:x",
    "Category:2026–27 in European men's football": "تصنيف:x",
    "Category:2026–27 in European men's international football": "تصنيف:x",
    "Category:2026–27 U Sports season": "تصنيف:x",
    "Category:2026–27 UEFA Conference League": "تصنيف:x",
    "Category:20th-century American newspaper publishers (people)": "تصنيف:x",
    "Category:21st-century Moroccan LGBTQ people": "تصنيف:x",
    "Category:Academic staff of Süleyman Demirel University": "تصنيف:x",
    "Category:Alumni of Teesside University": "تصنيف:x",
    "Category:American soccer clubs 2026 season": "تصنيف:x",
    "Category:Amusement rides planned to open in 2026": "تصنيف:x",
    "Category:Antiquities in Pushkin Museum": "تصنيف:x",
    "Category:Assam MLAs 2021–2026": "تصنيف:x",
    "Category:Azad Kashmir MLAs 2021–2026": "تصنيف:x",
    "Category:Battle of Greece": "تصنيف:x",
    "Category:Countries in the Eurovision Song Contest 2026": "تصنيف:x",
    "Category:Eurovision Song Contest 2026": "تصنيف:x",
    "Category:Founders of Sciences Po": "تصنيف:x",
    "Category:Great Britain national baseball team": "تصنيف:x",
    "Category:India Meteorological Department": "تصنيف:x",
    "Category:Justice ministers of Andalusia": "تصنيف:x",
    "Category:Kerala MLAs 2021–2026": "تصنيف:x",
    "Category:Major League Volleyball (2026)": "تصنيف:x",
    "Category:Mass media occupations": "تصنيف:x",
    "Category:Members of the Election Committee of Hong Kong": "تصنيف:x",
    "Category:Members of the Folketing 2022–2026": "تصنيف:x",
    "Category:Members of the House of Keys 2021–2026": "تصنيف:x",
    "Category:Out of copyright in 2026": "تصنيف:x",
    "Category:Planning ministers of Puntland": "تصنيف:x",
    "Category:Puducherry MLAs 2021–2026": "تصنيف:x",
    "Category:Railway stations scheduled to open in 2026": "تصنيف:x",
    "Category:Rodez AF": "تصنيف:x",
    "Category:Rohingya people": "تصنيف:x",
    "Category:Scottish Parliament constituencies and regions from 2026": "تصنيف:x",
    "Category:Screenshots of films out of copyright in 2026": "تصنيف:x",
    "Category:Short-track speed skating at the 2026 Winter Olympics": "تصنيف:x",
    "Category:Ski mountaineering at the 2026 Winter Olympics": "تصنيف:x",
    "Category:Tamil Nadu MLAs 2021–2026": "تصنيف:x",
    "Category:Tennessee Technological University": "تصنيف:x",
    "Category:Texas A&M University faculty": "تصنيف:x",
    "Category:Train-related introductions in 2026": "تصنيف:x",
    "Category:UK councillors 2022–2026": "تصنيف:x",
    "Category:Wales MSs 2021–2026": "تصنيف:x",
    "Category:West Bengal MLAs 2021–2026": "تصنيف:x",
    "Category:West Coast hip-hop musicians": "تصنيف:x",
    "Category:Women government ministers of Nauru": "تصنيف:x",
    "Category:Yi people": "تصنيف:x",
}

to_test = [
    ("test_2026_data_1", data1),
    ("test_2026_data_2", data2),
    # ("test_2026_data_3", data3),
]


@pytest.mark.parametrize("category, expected", data1.items(), ids=data1.keys())
@pytest.mark.skip2
def test_2026_data_1(category: str, expected: str) -> None:
    assert resolve_arabic_category_label(category) == expected


@pytest.mark.parametrize("name,data", to_test)
# @pytest.mark.skip
@pytest.mark.dump
def test_dump_it(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)
    dump_diff(diff_result, name)

    # dump_same_and_not_same(data, expected, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



from __future__ import annotations

import pytest

from ArWikiCats.translations.sports import _helpers, cycling


def test_extend_with_templates_preserves_positional_placeholders() -> None:
    target: dict[str, str] = {}
    templates = {"{} national team": "{} national team {year}"}

    _helpers.extend_with_templates(target, templates, year=2024)

    assert target == {"{} national team": "{} national team 2024"}


def test_extend_with_year_templates_default_years() -> None:
    target: dict[str, str] = {}

    _helpers.extend_with_year_templates(target, {"under-{year}": "under {year}"})

    expected = {f"under-{year}": f"under {year}" for year in _helpers.YEARS}
    assert target == expected


def test_build_cycling_templates_produces_derivative_keys() -> None:
    templates = cycling.build_cycling_templates()
    base_label = cycling.BASE_CYCLING_EVENTS["tour de france"]

    assert templates["tour de france"] == base_label
    assert templates["tour de france media"] == f"إعلام {base_label}"
    assert templates["tour de france stage winners"] == f"فائزون في مراحل {base_label}"


def test_cycling_aliases_match_primary_templates() -> None:
    assert cycling.CYCLING_TEMPLATES is cycling.CYCLING_TEMPLATES
    assert cycling.CYCLING_TEMPLATES is cycling.CYCLING_TEMPLATES



"""
pytest tests/big_data/test_big.py -m dumpbig
"""

import json
from pathlib import Path

import pytest
from load_one_data import dump_diff, dump_same_and_not_same, one_dump_test

from ArWikiCats import resolve_arabic_category_label


@pytest.fixture
def load_json_data(request):
    file_path = request.param
    if not file_path.exists():
        return {}  # أو pytest.skip(f"File {file_path} not found")
    with open(file_path, "r", encoding="utf-8") as f:
        return json.load(f)


def run_dump_logic(name, data):
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)
    dump_diff(diff_result, name)

    # expected2 = {x: v for x, v in expected.items() if v and x in diff_result}
    # dump_diff(expected2, f"{name}_expected")
    dump_same_and_not_same(data, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"


JSON_FILES = list((Path(__file__).parent.parent.parent / "examples/religions_data").glob("*.json"))


@pytest.mark.dumpbig
@pytest.mark.parametrize("load_json_data", JSON_FILES, indirect=True, ids=lambda p: f"test_big_{p.name}")
def test_religions_big_data(load_json_data, request) -> None:
    name = request.node.callspec.id
    run_dump_logic(name, load_json_data)



#!/usr/bin/python3
"""
Arabic Label Builder Module
"""

import functools
import re
from dataclasses import dataclass
from typing import Tuple

from ...format_bots.relation_mapping import translation_category_relations
from ...helps import logger
from ...time_resolvers.labs_years_resolver import resolve_lab_from_years_patterns
from ...translations import pop_of_without_in
from ...utils import fix_minor
from .. import with_years_bot
from ..ma_bots.country_bot import event2_d2
from ..make_bots.bot_2018 import get_pop_All_18
from ..matables_bots.check_bot import check_key_new_players
from ..matables_bots.data import Keep_it_frist, Keep_it_last
from ..o_bots import univer
from .lab import (
    get_con_lab,
    get_type_country,
    get_type_lab,
)
from .year_or_typeo import label_for_startwith_year_or_typeo

separators_lists_raw = [
    "in",
    "from",
    "at",
    "by",
    "of",
]


def _should_add_preposition_fe(type_label: str, type_lower: str) -> bool:
    """Check if 'في' should be added to the label.

    Args:
        type_label: The Arabic label.
        type_lower: The lowercase type string.

    Returns:
        bool: True if 'في' should be added, False otherwise.
    """
    return " في" not in type_label and " in" in type_lower


def _handle_in_separator(type_label: str, separator_stripped: str, type_lower: str) -> str:
    """Handle 'in' separator logic.

    Args:
        type_label: The current Arabic label.
        separator_stripped: The stripped separator.
        type_lower: The lowercase type string.

    Returns:
        str: The modified type label.
    """
    # Skip if type is in exception list
    if type_lower in pop_of_without_in:
        logger.info(f'>>-- Skip add في to {type_label=}, "{type_lower}"')
        return type_label

    # Add 'في' if conditions are met
    if _should_add_preposition_fe(type_label, type_lower):
        logger.info(f'>>-- Add في to type_label:in"{type_label}", for "{type_lower}"')
        return f"{type_label} في"

    return type_label


def _handle_at_separator(type_label: str, type_lower: str) -> str:
    """Handle 'at' separator logic.

    Args:
        type_label: The current Arabic label.
        type_lower: The lowercase type string.

    Returns:
        str: The modified type label.
    """
    if " في" not in type_label:
        logger.info(f'>>>> Add في to type_label:at"{type_label}"')
        return f"{type_label} في"

    return type_label


def separator_lists_fixing(type_label: str, separator_stripped: str, type_lower: str) -> str:
    """Add appropriate Arabic preposition to the type label based on the separator.

    Adds 'في' (in/at) to the Arabic label when appropriate based on the English separator
    and the type string content.

    Args:
        type_label: The current Arabic label for the type (e.g., "منشآت عسكرية").
        separator_stripped: The stripped English separator (e.g., "in", "at").
        type_lower: The lowercase type string (e.g., "military installations").

    Returns:
        str: The modified type label with preposition if applicable.

    Example:
        >>> separator_lists_fixing("منشآت عسكرية", "in", "military installations")
        "منشآت عسكرية في"
    """
    # Early return if separator is not in the raw list
    if separator_stripped not in separators_lists_raw:
        return type_label

    # Handle 'in' separator
    if separator_stripped == "in" or " in" in type_lower:
        return _handle_in_separator(type_label, separator_stripped, type_lower)

    # Handle 'at' separator
    if separator_stripped == "at" or " at" in type_lower:
        return _handle_at_separator(type_label, type_lower)

    return type_label


def _should_add_min_for_from_separator(type_label: str) -> bool:
    """Check if 'من' should be added for 'from' separator.

    Args:
        type_label: The current Arabic label.

    Returns:
        bool: True if 'من' should be added, False otherwise.
    """
    return not type_label.strip().endswith(" من")


def _should_add_min_for_of_suffix(type_lower: str, ty_in18: str, type_label: str, type_lower_prefix: str = "") -> bool:
    """Check if 'من' should be added for ' of' suffix.

    Args:
        type_lower: The lowercase type string.
        ty_in18: The result from get_pop_All_18.
        type_label: The current Arabic label.

    Returns:
        bool: True if 'من' should be added, False otherwise.
    """
    # Check basic conditions
    if not ty_in18:
        return False

    if not type_lower.endswith(" of"):
        return False

    skip_in = [
        "مدربو",
    ]

    if type_label in skip_in:
        return False

    if pop_of_without_in.get(type_lower) or pop_of_without_in.get(type_lower_prefix):
        return False

    if " في" in type_label:
        return False

    return True


def add_in_tab(type_label: str, type_lower: str, separator_stripped: str) -> str:
    """Add 'من' (from) to the label if conditions are met.

    This function adds the Arabic preposition 'من' (from/of) to the type label based on:
    1. The separator being 'from'
    2. The type ending with ' of' and being found in certain tables

    Args:
        type_label: The current Arabic label for the type.
        type_lower: The lowercase type string.
        separator_stripped: The stripped delimiter.

    Returns:
        str: The modified type label with 'من' if applicable.

    Example:
        >>> add_in_tab("رياضيون", "athletes", "from")
        "رياضيون من "
    """
    # Handle 'from' separator
    if separator_stripped == "from":
        if _should_add_min_for_from_separator(type_label):
            logger.info(f">>>> Add من to type_label '{type_label}' (separator: from)")
            return f"{type_label} من "
        return type_label

    # Get population data for type
    ty_in18 = get_pop_All_18(type_lower)

    # Extract type without ' of' suffix
    type_lower_prefix = type_lower.removesuffix(" of")

    # Check if we should add 'من' for ' of' suffix
    if not _should_add_min_for_of_suffix(type_lower, ty_in18, type_label, type_lower_prefix):
        return type_label

    # Check if type (with or without ' of') is in tables
    in_tables = check_key_new_players(type_lower)
    in_tables_prefix = check_key_new_players(type_lower_prefix)

    if in_tables or in_tables_prefix:
        logger.info(f">>>> Add من to type_label '{type_label}' (ends with ' of')")
        return f"{type_label} من "

    return type_label


@functools.lru_cache(maxsize=10000)
def wrap_event2(category: str, separator: str = "") -> str:
    """Wraps the event2bot.event2 function with caching."""
    result = (
        univer.te_universities(category)
        or event2_d2(category)
        or with_years_bot.Try_With_Years2(category)
        or label_for_startwith_year_or_typeo(category)
        or ""
    )
    return result


@dataclass
class ParsedCategory:
    """Represents a parsed category with its components."""

    category: str
    separator: str
    type_value: str
    country: str


class CountryResolver:
    """Resolves country-related information for category labeling."""

    @staticmethod
    @functools.lru_cache(maxsize=10000)
    def resolve_labels(preposition: str, country: str, start_get_country2: bool = True) -> str:
        """Resolve the country label."""
        return get_con_lab(preposition, country, start_get_country2)


class TypeResolver:
    """Resolves type-related information for category labeling."""

    @staticmethod
    @functools.lru_cache(maxsize=10000)
    def resolve(preposition: str, type_value: str, country_lower: str, use_event2: bool = True) -> Tuple[str, bool]:
        """Resolve the type label and whether to append 'in' label."""
        type_lower = type_value.strip().lower()

        logger.debug(f'>>>>> > Resolving type: "{type_lower}", preposition: "{preposition}"')

        type_label = resolve_lab_from_years_patterns(type_lower)
        if type_label:
            return type_label, True

        type_label, add_in_lab = get_type_lab(preposition, type_value)

        # Special handling for sport and by
        if type_lower == "sport" and country_lower.startswith("by "):
            type_label = "رياضة"

        # Use event2 if no type label found
        if not type_label and use_event2:
            type_label = wrap_event2(type_lower, preposition)

        return type_label, add_in_lab


class Fixing:
    def __init__(self) -> None:
        pass

    def determine_separator(self) -> str:
        """Determines the separator string between labels."""
        ar_separator = " "
        if self.separator_stripped == "in":
            ar_separator = " في "

        if (self.separator_stripped == "in" or self.separator_stripped == "at") and (" في" not in self.type_label):
            self.type_label = self.type_label + " في"

        if self.add_in_lab:
            logger.info(f">>>>> > add_in_lab ({self.separator_stripped=})")
            separator2_lab = translation_category_relations.get(self.separator_stripped)

            if separator2_lab not in separators_lists_raw:
                tatl = separator2_lab
                logger.info(
                    f">>>>> > ({self.separator_stripped=}): separator_stripped in category_relation_mapping and separator_stripped not in separators_lists_raw, {tatl=}"
                )

                if self.separator_stripped == "for" and self.country_lower.startswith("for "):
                    if self.type_lower.strip().endswith("competitors") and "competitors for" in self.category:
                        tatl = "من"
                    if self.type_lower.strip().endswith("medalists") and "medalists for" in self.category:
                        tatl = "من"

                if self.separator_stripped == "to" and self.type_lower.strip().startswith("ambassadors of"):
                    tatl = "لدى"

                if self.country_label == "لعضوية البرلمان":
                    tatl = ""

                if self.separator_stripped == "for" and self.country_lower.startswith("for "):
                    p18lab = get_pop_All_18(self.country_lower)
                    if p18lab and p18lab == self.country_label:
                        tatl = ""

                for_table = {
                    "for national teams": "للمنتخبات الوطنية",
                    "for member-of-parliament": "لعضوية البرلمان",
                }

                if self.country_lower in for_table:
                    tatl = ""

                ar_separator = f" {tatl} "
                logger.info("ar_separator:%s" % ar_separator)
                self.cate_test = self.cate_test.replace(self.separator, "")

        # in_tables_1 = check_key_new_players(self.country_lower)
        # in_tables_2 = check_key_new_players(self.type_lower)

        # if in_tables_1 and in_tables_2:
        logger.info(">>>> ================ ")
        logger.info(">>>>> > X:<<lightred>> type_lower and country_lower in players_new_keys.")
        logger.info(">>>> ================ ")

        faa = translation_category_relations.get(self.separator_stripped) or translation_category_relations.get(
            self.separator_stripped.replace("-", " ").strip()
        )

        if not ar_separator.strip() and faa:
            ar_separator = f" {faa} "

        return ar_separator


class LabelPipeline(Fixing):
    """
    A class to handle the construction of Arabic labels from category strings.
    """

    def __init__(
        self,
        category: str,
        separator: str,
        cate_test: str = "",
        start_get_country2: bool = True,
        use_event2: bool = True,
    ):
        self.category = category
        self.separator = separator
        self.cate_test = cate_test
        self.start_get_country2 = start_get_country2
        self.use_event2 = use_event2

        self.separator_stripped = separator.strip()
        self.category_type = ""
        self.country = ""
        self.type_lower = ""
        self.country_lower = ""

        self.type_label = ""
        self.country_label = ""
        self.should_append_in_label = True
        self.add_in_lab = True  # Renamed from add_in_lab for consistency but keeping logic

    def extract_components(self) -> None:
        """Extracts type and country components."""
        self.category_type, self.country = get_type_country(self.category, self.separator)
        self.type_lower = self.category_type.strip().lower()
        self.country_lower = self.country.strip().lower()

    def resolve_labels(self) -> bool:
        """Resolves type and country labels. Returns False if resolution fails."""

        # Resolve type
        self.type_label, self.add_in_lab = TypeResolver.resolve(
            self.separator_stripped, self.category_type, self.country_lower, self.use_event2
        )

        if self.type_label:
            self.cate_test = self.cate_test.replace(self.type_lower, "")

        # Resolve country
        self.country_label = CountryResolver.resolve_labels(
            self.separator_stripped, self.country, self.start_get_country2
        )

        if self.country_label:
            self.cate_test = self.cate_test.replace(self.country_lower, "")

        # Validation
        cao = True
        if not self.type_label:
            logger.info(f">>>> no label for {self.type_lower=}")
            cao = False

        if not self.country_label:
            logger.info(f'>>>> country_lower not in pop new "{self.country_lower}"')
            cao = False

        if self.type_label or self.country_label:
            logger.info(
                f'<<lightgreen>>>>>> ------------- country_lower:"{self.country_lower}", country_label:"{self.country_label}"'
            )
            logger.info(
                f'<<lightgreen>>>>>> ------------- type_lower:"{self.type_lower}", type_label:"{self.type_label}"'
            )

        if not cao:
            return False

        logger.info(f'<<lightblue>> CAO: cat:"{self.category}":')

        if not self.type_label or not self.country_label:
            return False

        return True

    def refine_type_label(self) -> None:
        """Refines the type label with prepositions."""

        excluded_type_labels_from_min = [
            "women of",
            "founders of",
        ]

        if self.add_in_lab:
            self.type_label = separator_lists_fixing(self.type_label, self.separator_stripped, self.type_lower)
            if self.type_lower in excluded_type_labels_from_min:
                logger.info(f'>>>> type_lower "{self.type_lower}" in excluded_type_labels_from_min ')
            else:
                self.type_label = add_in_tab(self.type_label, self.type_lower, self.separator_stripped)

    def join_labels(self, ar_separator: str) -> str:
        """Constructs the final Arabic label."""
        keep_type_last = False
        keep_type_first = False

        arlabel = ""
        t_to = f"{self.type_lower} {self.separator_stripped}"

        if self.type_lower in Keep_it_last:
            logger.info(f">>>>> > X:<<lightred>> keep_type_last = True, {self.type_lower=} in Keep_it_last")
            keep_type_last = True

        elif self.type_lower in Keep_it_frist:
            logger.info(f">>>>> > X:<<lightred>> keep_type_first = True, {self.type_lower=} in Keep_it_frist")
            keep_type_first = True

        elif t_to in Keep_it_frist:
            logger.info(f">>>>> > X:<<lightred>> keep_type_first = True, {t_to=} in Keep_it_frist")
            keep_type_first = True

        arlabel = self.type_label + ar_separator + self.country_label

        if keep_type_last:
            logger.info(f">>>>> > X:<<lightred>> keep_type_last = True, {self.type_lower=} in Keep_it_last")
            arlabel = self.country_label + ar_separator + self.type_label

        elif keep_type_first:
            logger.info(f">>>>> > X:<<lightred>> keep_type_first = True, {self.type_lower=} in Keep_it_frist")
            arlabel = self.type_label + ar_separator + self.country_label

        if self.separator_stripped == "about" or (self.separator_stripped not in separators_lists_raw):
            arlabel = self.type_label + ar_separator + self.country_label

        if self.type_lower == "years" and self.separator_stripped == "in":
            arlabel = self.type_label + ar_separator + self.country_label

        logger.debug(f">>>> {ar_separator=}")
        logger.debug(f">>>> {arlabel=}")

        arlabel = " ".join(arlabel.strip().split())
        maren = re.match(r"\d\d\d\d", self.country_lower.strip())
        if self.type_lower.lower() == "the war of" and maren and arlabel == f"الحرب في {self.country_lower}":
            arlabel = f"حرب {self.country_lower}"
            logger.info(f'<<lightpurple>> >>>> change arlabel to "{arlabel}".')

        return arlabel

    def build(self) -> str:
        """Builds and returns the Arabic label."""
        logger.info(f'<<lightblue>>>>>> find_ar_label: category="{self.category}", separator="{self.separator}"')

        self.extract_components()

        if not self.resolve_labels():
            return ""

        self.refine_type_label()

        ar_separator = self.determine_separator()
        arlabel = self.join_labels(ar_separator)

        logger.info(f'>>>> <<lightblue>>cate_test :"{self.cate_test}"')
        logger.info(f'>>>>>> <<lightyellow>>test: cat "{self.category}", {arlabel=}')

        arlabel = arlabel.strip()
        arlabel = fix_minor(arlabel, ar_separator, self.category)

        return arlabel


@functools.lru_cache(maxsize=10000)
def find_ar_label(
    category: str,
    separator: str,
    cate_test: str = "",
    start_get_country2: bool = True,
    use_event2: bool = True,
) -> str:
    """Find the Arabic label based on the provided parameters.

    This function now uses the LabelPipeline class to perform the logic.
    """
    builder = LabelPipeline(
        category=category,
        separator=separator,
        cate_test=cate_test,
        start_get_country2=start_get_country2,
        use_event2=use_event2,
    )
    return builder.build()


__all__ = [
    "find_ar_label",
]



"""
Tests
"""

import pytest

from ArWikiCats.new_resolvers.resolve_languages import resolve_languages_labels
from ArWikiCats.translations import LANGUAGE_TOPIC_FORMATS, language_key_translations

language_key_translations = {k: language_key_translations[k] for k in list(language_key_translations.keys())[:10]}

# A real language key that exists in language_key_translations
BASE_LANG = "abkhazian-language"
BASE_LANG_OUTPUT = "اللغة الأبخازية"


@pytest.mark.parametrize("suffix,template", LANGUAGE_TOPIC_FORMATS.items())
def testlang_key_m_patterns(suffix: str, template: str) -> None:
    # builds: "<lang> <suffix>"
    category = f"{BASE_LANG} {suffix}"
    result = resolve_languages_labels(category)

    # expected formatting
    expected = template.format(BASE_LANG_OUTPUT)

    assert result == expected, (
        f"LANGUAGE_TOPIC_FORMATS mismatch for '{category}'\n" f" {expected=}\n" f"Got:      {result}"
    )


@pytest.mark.parametrize("lang,expected", language_key_translations.items())
def test_directlanguages_key_lookup(lang: str, expected: str) -> None:
    result = resolve_languages_labels(lang)
    assert result == expected, (
        f"language_key_translations lookup mismatch for '{lang}'\n" f" {expected=}\n" f"Got:      {result}"
    )


def test_sample_direct_language() -> None:
    # from _languages_key
    assert resolve_languages_labels("abkhazian language") == "لغة أبخازية"
    assert resolve_languages_labels("afrikaans-language") == "اللغة الإفريقية"
    assert resolve_languages_labels("albanian languages") == "اللغات الألبانية"


def test_sample_lang_key_m_albums() -> None:
    # "albums": "ألبومات ب{}",
    result = resolve_languages_labels("abkhazian-language albums")
    assert result == "ألبومات باللغة الأبخازية"


def test_sample_lang_key_m_categories() -> None:
    # "categories": "تصنيفات {}",
    result = resolve_languages_labels("abkhazian-language categories")
    assert result == "تصنيفات اللغة الأبخازية"


def test_sample_lang_key_m_grammar() -> None:
    # "grammar": "قواعد اللغة ال{}",
    result = resolve_languages_labels("abkhazian-language grammar")
    assert result == "قواعد اللغة الأبخازية"


def test_sample_films_drama() -> None:
    # "action drama films": "أفلام حركة درامية {}",
    result = resolve_languages_labels("abkhazian-language action drama films")
    assert result == "أفلام حركة درامية باللغة الأبخازية"


def test_romanization_pattern() -> None:
    # "romanization of"
    result = resolve_languages_labels("romanization of abkhazian")
    assert result == "رومنة اللغة الأبخازية"


def test_films_pattern_basic() -> None:
    # "<lang> films" (no suffix)
    result = resolve_languages_labels("abkhazian-language films")
    assert result == "أفلام باللغة الأبخازية"


def test_no_match() -> None:
    assert resolve_languages_labels("abkhazian-language unknown unknown") == ""
    assert resolve_languages_labels("xyz something") == ""



from ...helps import logger
from . import (
    p17_bot_sport,
    p17_sport_to_move_under,
)


def resolved_names_with_sports(normalized_category) -> str:
    logger.debug(f"<><><><><><> <<green>> Trying resolved_names_with_sports for: {normalized_category=}")
    resolved_label = (
        #  [yemen international soccer players] : "تصنيف:لاعبو منتخب اليمن لكرة القدم",
        # countries_names.resolve_by_countries_names(normalized_category) or
        #  "lithuania men's under-21 international footballers": "لاعبو منتخب ليتوانيا تحت 21 سنة لكرة القدم للرجال"
        p17_sport_to_move_under.resolve_sport_under_labels(normalized_category)
        # [yemen international soccer players] : "تصنيف:لاعبو كرة قدم دوليون من اليمن",
        or p17_bot_sport.get_p17_with_sport_new(normalized_category)
        or ""
    )
    logger.info_if_or_debug(
        f"<<yellow>> end countries_names_resolvers: {normalized_category=}, {resolved_label=}", resolved_label
    )
    return resolved_label



import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_arabic_category_label

data1 = {
    "Category:People in arts occupations by nationality": "تصنيف:أشخاص في مهن فنية حسب الجنسية",
    "Category:People of Ivorian descent": "تصنيف:أشخاص من أصل إيفواري",
    "Category:Polish women by occupation": "تصنيف:بولنديات حسب المهنة",
    "Category:Portuguese healthcare managers": "تصنيف:مدراء رعاية صحية برتغاليون",
    "Category:Prisoners and detainees of Afghanistan": "تصنيف:سجناء ومعتقلون في أفغانستان",
    "Category:Prisons in Afghanistan": "تصنيف:سجون في أفغانستان",
    "Category:Scholars by subfield": "تصنيف:دارسون حسب الحقل الفرعي",
    "Category:Women in business by nationality": "تصنيف:سيدات أعمال حسب الجنسية",
    "Category:women in business": "تصنيف:سيدات أعمال",
}

data2 = {
    "Category:Iranian nuclear medicine physicians": "تصنيف:أطباء طب نووي إيرانيون",
    "Category:Israeli people of Northern Ireland descent": "تصنيف:إسرائيليون من أصل أيرلندي شمالي",
    "Category:Ivorian diaspora in Asia": "تصنيف:شتات إيفواري في آسيا",
    "Category:Medical doctors by specialty and nationality": "تصنيف:أطباء حسب التخصص والجنسية",
    "Category:Multi-instrumentalists": "تصنيف:عازفون على عدة آلات",
    "Category:People by nationality and status": "تصنيف:أشخاص حسب الجنسية والحالة",
}

data3 = {
    "Category:Canadian nuclear medicine physicians": "تصنيف:أطباء طب نووي كنديون",
    "Category:Croatian nuclear medicine physicians": "تصنيف:أطباء طب نووي كروات",
    "Category:Expatriate male actors in New Zealand": "تصنيف:ممثلون ذكور مغتربون في نيوزيلندا",
    "Category:Expatriate male actors": "تصنيف:ممثلون ذكور مغتربون",
    "Category:German nuclear medicine physicians": "تصنيف:أطباء طب نووي ألمان",
    "Category:Immigrants to New Zealand": "تصنيف:مهاجرون إلى نيوزيلندا",
    "Category:Immigration to New Zealand": "تصنيف:الهجرة إلى نيوزيلندا",
    "Category:Internees at the Sheberghan Prison": "تصنيف:معتقلون في سجن شيبرغان",
}


data4 = {
    "Category:Afghan diplomats": "تصنيف:دبلوماسيون أفغان",
    "Category:Ambassadors of Afghanistan": "تصنيف:سفراء أفغانستان",
    "Category:Ambassadors of the Ottoman Empire": "تصنيف:سفراء الدولة العثمانية",
    "Category:Ambassadors to the Ottoman Empire": "تصنيف:سفراء لدى الدولة العثمانية",
    "Category:American nuclear medicine physicians": "تصنيف:أطباء طب نووي أمريكيون",
    "Category:Argentine multi-instrumentalists": "تصنيف:عازفون على عدة آلات أرجنتينيون",
    "Category:Attacks on diplomatic missions": "تصنيف:هجمات على بعثات دبلوماسية",
    "Category:Australian Internet celebrities": "تصنيف:مشاهير إنترنت أستراليون",
}

to_test = [
    ("test_people_1", data1),
    ("test_people_2", data2),
    ("test_people_3", data3),
    ("test_people_4", data4),
]


@pytest.mark.parametrize("category, expected", data1.items(), ids=data1.keys())
@pytest.mark.fast
def test_people_1(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", data2.items(), ids=data2.keys())
@pytest.mark.fast
def test_people_2(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", data3.items(), ids=data3.keys())
@pytest.mark.fast
def test_people_3(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", data4.items(), ids=data4.keys())
@pytest.mark.fast
def test_people_4(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_peoples(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
